summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--Cross/Makefile-cross-SH9
-rw-r--r--MANIFEST3
-rwxr-xr-xMakefile.SH9
-rw-r--r--Makefile.micro2
-rw-r--r--NetWare/Makefile2
-rwxr-xr-xPorting/makerel1
-rw-r--r--embed.h367
-rw-r--r--embedvar.h2
-rw-r--r--global.sym2
-rw-r--r--gv.c2
-rw-r--r--op.c4
-rw-r--r--perlapi.c2
-rw-r--r--perlapi.h2
-rw-r--r--pp.sym374
-rw-r--r--pp_ctl.c14
-rw-r--r--pp_hot.c2
-rw-r--r--pp_proto.h375
-rw-r--r--pp_sys.c4
-rw-r--r--proto.h370
-rw-r--r--regen.pl3
-rwxr-xr-xregen/embed.pl37
-rwxr-xr-xregen/opcode.pl33
-rw-r--r--vms/descrip_mms.template3
-rw-r--r--win32/Makefile2
-rw-r--r--win32/Makefile.ce2
-rw-r--r--win32/makefile.mk2
26 files changed, 436 insertions, 1192 deletions
diff --git a/Cross/Makefile-cross-SH b/Cross/Makefile-cross-SH
index 21f83275eb..d41f1bdd9c 100644
--- a/Cross/Makefile-cross-SH
+++ b/Cross/Makefile-cross-SH
@@ -839,7 +839,7 @@ perly.h: perly.y
# No compat3.sym here since and including the 5.004_50.
# No interp.sym since 5.005_03.
-SYM = global.sym globvar.sym perlio.sym pp.sym
+SYM = global.sym globvar.sym perlio.sym
SYMH = perlvars.h intrpvar.h
@@ -848,9 +848,8 @@ CHMOD_W = chmod +w
# The following files are generated automatically
# embed.pl: proto.h embed.h embedvar.h global.sym
# perlapi.h perlapi.c
-# [* embed.pl needs pp.sym generated by opcode.pl! *]
# keywords.pl: keywords.h
-# opcode.pl: opcode.h opnames.h pp.sym
+# opcode.pl: opcode.h opnames.h pp_proto.h
# regcomp.pl: regnodes.h
# warnings.pl: warnings.h lib/warnings.pm
# The correct versions should be already supplied with the perl kit,
@@ -860,7 +859,7 @@ CHMOD_W = chmod +w
# with your existing copy of perl
# (make regen_headers is kept for backwards compatibility)
-AUTOGEN_FILES = keywords.h opcode.h opnames.h pp.sym proto.h \
+AUTOGEN_FILES = keywords.h opcode.h opnames.h pp_proto.h proto.h \
embed.h embedvar.h global.sym \
perlapi.h perlapi.c regnodes.h \
warnings.h lib/warnings.pm
@@ -966,7 +965,7 @@ _mopup:
-rm -f perl.Addrs perl.Counts t/perl.Addrs t/perl.Counts *perl.xok
-rm -f cygwin.c libperl*.def libperl*.dll cygperl*.dll *.exe.stackdump
-rm -f perl$(EXE_EXT) miniperl$(EXE_EXT) $(LIBPERL) libperl.* microperl
- -rm -f opcode.h-old opnames.h-old pp.sym-old
+ -rm -f opcode.h-old opnames.h-old pp_proto.h-old
-rm -f config.over
# Do not 'make _tidy' directly.
diff --git a/MANIFEST b/MANIFEST
index 68184eddd1..c51a4f12c8 100644
--- a/MANIFEST
+++ b/MANIFEST
@@ -4385,9 +4385,8 @@ pp_ctl.c Push/Pop code for control flow
pp.h Push/Pop code defs
pp_hot.c Push/Pop code for heavily used opcodes
pp_pack.c Push/Pop code for pack/unpack
-pp_proto.h Not needed, but EU::MM currently references it
+pp_proto.h C++ definitions for Push/Pop code
pp_sort.c Push/Pop code for sort
-pp.sym Push/Pop code symbols
pp_sys.c Push/Pop code for system interaction
proto.h Prototypes
qnx/ar QNX implementation of "ar" utility
diff --git a/Makefile.micro b/Makefile.micro
index 3528b93296..86113322d7 100644
--- a/Makefile.micro
+++ b/Makefile.micro
@@ -29,7 +29,7 @@ microperl: $(O)
H = av.h uconfig.h cop.h cv.h embed.h embedvar.h form.h gv.h handy.h \
hv.h intrpvar.h iperlsys.h mg.h op.h opcode.h opnames.h pad.h \
patchlevel.h perl.h perlsdio.h perlvars.h perly.h pp.h \
- proto.h reentr.h regexp.h scope.h sv.h \
+ pp_proto.h proto.h reentr.h regexp.h scope.h sv.h \
thread.h unixish.h utf8.h util.h uudmap.h warnings.h
HE = $(H) EXTERN.h
diff --git a/NetWare/Makefile b/NetWare/Makefile
index 426561a621..3fb7156af6 100644
--- a/NetWare/Makefile
+++ b/NetWare/Makefile
@@ -1063,7 +1063,7 @@ $(PERLIMPLIB): perllib.imp
# $(XCOPY) $(PERLIMPLIB) $(COREDIR)
# @echo $(PERLIMPLIB) Done
-perllib.imp : $(MINIPERL) $(CONFIGPM) ..\global.sym ..\pp.sym ..\makedef.pl
+perllib.imp : $(MINIPERL) $(CONFIGPM) ..\global.sym ..\makedef.pl
# $(MINIPERL) -w ..\makedef.pl PLATFORM=netware FILETYPE=def $(ADD_BUILDOPT) \
# CCTYPE=$(CCTYPE) > perllib.def
@echo (Perl) > perl.imp
diff --git a/Porting/makerel b/Porting/makerel
index 39730b3d60..046cd67ac5 100755
--- a/Porting/makerel
+++ b/Porting/makerel
@@ -135,7 +135,6 @@ my @writables = qw(
opcode.h
opnames.h
pp_proto.h
- pp.sym
proto.h
embed.h
embedvar.h
diff --git a/embed.h b/embed.h
index 54b7c68cc3..54e92efbbe 100644
--- a/embed.h
+++ b/embed.h
@@ -10,7 +10,7 @@
*
* !!!!!!! DO NOT EDIT THIS FILE !!!!!!!
* This file is built by regen/embed.pl from data in embed.fnc,
- * regen/embed.pl, pp.sym, intrpvar.h, and perlvars.h.
+ * regen/embed.pl, regen/opcodes intrpvar.h, and perlvars.h.
* Any changes made here will be lost!
*
* Edit those files and run 'make regen_headers' to effect changes.
@@ -1091,371 +1091,6 @@
#define parser_free(a) Perl_parser_free(aTHX_ a)
#define peep(a) Perl_peep(aTHX_ a)
#define pmruntime(a,b,c) Perl_pmruntime(aTHX_ a,b,c)
-#define pp_aassign() Perl_pp_aassign(aTHX)
-#define pp_abs() Perl_pp_abs(aTHX)
-#define pp_accept() Perl_pp_accept(aTHX)
-#define pp_add() Perl_pp_add(aTHX)
-#define pp_aeach() Perl_pp_aeach(aTHX)
-#define pp_aelem() Perl_pp_aelem(aTHX)
-#define pp_aelemfast() Perl_pp_aelemfast(aTHX)
-#define pp_akeys() Perl_pp_akeys(aTHX)
-#define pp_alarm() Perl_pp_alarm(aTHX)
-#define pp_and() Perl_pp_and(aTHX)
-#define pp_andassign() Perl_pp_andassign(aTHX)
-#define pp_anoncode() Perl_pp_anoncode(aTHX)
-#define pp_anonhash() Perl_pp_anonhash(aTHX)
-#define pp_anonlist() Perl_pp_anonlist(aTHX)
-#define pp_aslice() Perl_pp_aslice(aTHX)
-#define pp_atan2() Perl_pp_atan2(aTHX)
-#define pp_av2arylen() Perl_pp_av2arylen(aTHX)
-#define pp_avalues() Perl_pp_avalues(aTHX)
-#define pp_backtick() Perl_pp_backtick(aTHX)
-#define pp_bind() Perl_pp_bind(aTHX)
-#define pp_binmode() Perl_pp_binmode(aTHX)
-#define pp_bit_and() Perl_pp_bit_and(aTHX)
-#define pp_bit_or() Perl_pp_bit_or(aTHX)
-#define pp_bit_xor() Perl_pp_bit_xor(aTHX)
-#define pp_bless() Perl_pp_bless(aTHX)
-#define pp_boolkeys() Perl_pp_boolkeys(aTHX)
-#define pp_break() Perl_pp_break(aTHX)
-#define pp_caller() Perl_pp_caller(aTHX)
-#define pp_chdir() Perl_pp_chdir(aTHX)
-#define pp_chmod() Perl_pp_chmod(aTHX)
-#define pp_chomp() Perl_pp_chomp(aTHX)
-#define pp_chop() Perl_pp_chop(aTHX)
-#define pp_chown() Perl_pp_chown(aTHX)
-#define pp_chr() Perl_pp_chr(aTHX)
-#define pp_chroot() Perl_pp_chroot(aTHX)
-#define pp_close() Perl_pp_close(aTHX)
-#define pp_closedir() Perl_pp_closedir(aTHX)
-#define pp_complement() Perl_pp_complement(aTHX)
-#define pp_concat() Perl_pp_concat(aTHX)
-#define pp_cond_expr() Perl_pp_cond_expr(aTHX)
-#define pp_connect() Perl_pp_connect(aTHX)
-#define pp_const() Perl_pp_const(aTHX)
-#define pp_continue() Perl_pp_continue(aTHX)
-#define pp_cos() Perl_pp_cos(aTHX)
-#define pp_crypt() Perl_pp_crypt(aTHX)
-#define pp_dbmclose() Perl_pp_dbmclose(aTHX)
-#define pp_dbmopen() Perl_pp_dbmopen(aTHX)
-#define pp_dbstate() Perl_pp_dbstate(aTHX)
-#define pp_defined() Perl_pp_defined(aTHX)
-#define pp_delete() Perl_pp_delete(aTHX)
-#define pp_die() Perl_pp_die(aTHX)
-#define pp_divide() Perl_pp_divide(aTHX)
-#define pp_dofile() Perl_pp_dofile(aTHX)
-#define pp_dor() Perl_pp_dor(aTHX)
-#define pp_dorassign() Perl_pp_dorassign(aTHX)
-#define pp_dump() Perl_pp_dump(aTHX)
-#define pp_each() Perl_pp_each(aTHX)
-#define pp_egrent() Perl_pp_egrent(aTHX)
-#define pp_ehostent() Perl_pp_ehostent(aTHX)
-#define pp_enetent() Perl_pp_enetent(aTHX)
-#define pp_enter() Perl_pp_enter(aTHX)
-#define pp_entereval() Perl_pp_entereval(aTHX)
-#define pp_entergiven() Perl_pp_entergiven(aTHX)
-#define pp_enteriter() Perl_pp_enteriter(aTHX)
-#define pp_enterloop() Perl_pp_enterloop(aTHX)
-#define pp_entersub() Perl_pp_entersub(aTHX)
-#define pp_entertry() Perl_pp_entertry(aTHX)
-#define pp_enterwhen() Perl_pp_enterwhen(aTHX)
-#define pp_enterwrite() Perl_pp_enterwrite(aTHX)
-#define pp_eof() Perl_pp_eof(aTHX)
-#define pp_eprotoent() Perl_pp_eprotoent(aTHX)
-#define pp_epwent() Perl_pp_epwent(aTHX)
-#define pp_eq() Perl_pp_eq(aTHX)
-#define pp_eservent() Perl_pp_eservent(aTHX)
-#define pp_exec() Perl_pp_exec(aTHX)
-#define pp_exists() Perl_pp_exists(aTHX)
-#define pp_exit() Perl_pp_exit(aTHX)
-#define pp_exp() Perl_pp_exp(aTHX)
-#define pp_fcntl() Perl_pp_fcntl(aTHX)
-#define pp_fileno() Perl_pp_fileno(aTHX)
-#define pp_flip() Perl_pp_flip(aTHX)
-#define pp_flock() Perl_pp_flock(aTHX)
-#define pp_flop() Perl_pp_flop(aTHX)
-#define pp_fork() Perl_pp_fork(aTHX)
-#define pp_formline() Perl_pp_formline(aTHX)
-#define pp_ftatime() Perl_pp_ftatime(aTHX)
-#define pp_ftbinary() Perl_pp_ftbinary(aTHX)
-#define pp_ftblk() Perl_pp_ftblk(aTHX)
-#define pp_ftchr() Perl_pp_ftchr(aTHX)
-#define pp_ftctime() Perl_pp_ftctime(aTHX)
-#define pp_ftdir() Perl_pp_ftdir(aTHX)
-#define pp_fteexec() Perl_pp_fteexec(aTHX)
-#define pp_fteowned() Perl_pp_fteowned(aTHX)
-#define pp_fteread() Perl_pp_fteread(aTHX)
-#define pp_ftewrite() Perl_pp_ftewrite(aTHX)
-#define pp_ftfile() Perl_pp_ftfile(aTHX)
-#define pp_ftis() Perl_pp_ftis(aTHX)
-#define pp_ftlink() Perl_pp_ftlink(aTHX)
-#define pp_ftmtime() Perl_pp_ftmtime(aTHX)
-#define pp_ftpipe() Perl_pp_ftpipe(aTHX)
-#define pp_ftrexec() Perl_pp_ftrexec(aTHX)
-#define pp_ftrowned() Perl_pp_ftrowned(aTHX)
-#define pp_ftrread() Perl_pp_ftrread(aTHX)
-#define pp_ftrwrite() Perl_pp_ftrwrite(aTHX)
-#define pp_ftsgid() Perl_pp_ftsgid(aTHX)
-#define pp_ftsize() Perl_pp_ftsize(aTHX)
-#define pp_ftsock() Perl_pp_ftsock(aTHX)
-#define pp_ftsuid() Perl_pp_ftsuid(aTHX)
-#define pp_ftsvtx() Perl_pp_ftsvtx(aTHX)
-#define pp_fttext() Perl_pp_fttext(aTHX)
-#define pp_fttty() Perl_pp_fttty(aTHX)
-#define pp_ftzero() Perl_pp_ftzero(aTHX)
-#define pp_ge() Perl_pp_ge(aTHX)
-#define pp_gelem() Perl_pp_gelem(aTHX)
-#define pp_getc() Perl_pp_getc(aTHX)
-#define pp_getlogin() Perl_pp_getlogin(aTHX)
-#define pp_getpeername() Perl_pp_getpeername(aTHX)
-#define pp_getpgrp() Perl_pp_getpgrp(aTHX)
-#define pp_getppid() Perl_pp_getppid(aTHX)
-#define pp_getpriority() Perl_pp_getpriority(aTHX)
-#define pp_getsockname() Perl_pp_getsockname(aTHX)
-#define pp_ggrent() Perl_pp_ggrent(aTHX)
-#define pp_ggrgid() Perl_pp_ggrgid(aTHX)
-#define pp_ggrnam() Perl_pp_ggrnam(aTHX)
-#define pp_ghbyaddr() Perl_pp_ghbyaddr(aTHX)
-#define pp_ghbyname() Perl_pp_ghbyname(aTHX)
-#define pp_ghostent() Perl_pp_ghostent(aTHX)
-#define pp_glob() Perl_pp_glob(aTHX)
-#define pp_gmtime() Perl_pp_gmtime(aTHX)
-#define pp_gnbyaddr() Perl_pp_gnbyaddr(aTHX)
-#define pp_gnbyname() Perl_pp_gnbyname(aTHX)
-#define pp_gnetent() Perl_pp_gnetent(aTHX)
-#define pp_goto() Perl_pp_goto(aTHX)
-#define pp_gpbyname() Perl_pp_gpbyname(aTHX)
-#define pp_gpbynumber() Perl_pp_gpbynumber(aTHX)
-#define pp_gprotoent() Perl_pp_gprotoent(aTHX)
-#define pp_gpwent() Perl_pp_gpwent(aTHX)
-#define pp_gpwnam() Perl_pp_gpwnam(aTHX)
-#define pp_gpwuid() Perl_pp_gpwuid(aTHX)
-#define pp_grepstart() Perl_pp_grepstart(aTHX)
-#define pp_grepwhile() Perl_pp_grepwhile(aTHX)
-#define pp_gsbyname() Perl_pp_gsbyname(aTHX)
-#define pp_gsbyport() Perl_pp_gsbyport(aTHX)
-#define pp_gservent() Perl_pp_gservent(aTHX)
-#define pp_gsockopt() Perl_pp_gsockopt(aTHX)
-#define pp_gt() Perl_pp_gt(aTHX)
-#define pp_gv() Perl_pp_gv(aTHX)
-#define pp_gvsv() Perl_pp_gvsv(aTHX)
-#define pp_helem() Perl_pp_helem(aTHX)
-#define pp_hex() Perl_pp_hex(aTHX)
-#define pp_hintseval() Perl_pp_hintseval(aTHX)
-#define pp_hslice() Perl_pp_hslice(aTHX)
-#define pp_i_add() Perl_pp_i_add(aTHX)
-#define pp_i_divide() Perl_pp_i_divide(aTHX)
-#define pp_i_eq() Perl_pp_i_eq(aTHX)
-#define pp_i_ge() Perl_pp_i_ge(aTHX)
-#define pp_i_gt() Perl_pp_i_gt(aTHX)
-#define pp_i_le() Perl_pp_i_le(aTHX)
-#define pp_i_lt() Perl_pp_i_lt(aTHX)
-#define pp_i_modulo() Perl_pp_i_modulo(aTHX)
-#define pp_i_multiply() Perl_pp_i_multiply(aTHX)
-#define pp_i_ncmp() Perl_pp_i_ncmp(aTHX)
-#define pp_i_ne() Perl_pp_i_ne(aTHX)
-#define pp_i_negate() Perl_pp_i_negate(aTHX)
-#define pp_i_subtract() Perl_pp_i_subtract(aTHX)
-#define pp_index() Perl_pp_index(aTHX)
-#define pp_int() Perl_pp_int(aTHX)
-#define pp_ioctl() Perl_pp_ioctl(aTHX)
-#define pp_iter() Perl_pp_iter(aTHX)
-#define pp_join() Perl_pp_join(aTHX)
-#define pp_keys() Perl_pp_keys(aTHX)
-#define pp_kill() Perl_pp_kill(aTHX)
-#define pp_last() Perl_pp_last(aTHX)
-#define pp_lc() Perl_pp_lc(aTHX)
-#define pp_lcfirst() Perl_pp_lcfirst(aTHX)
-#define pp_le() Perl_pp_le(aTHX)
-#define pp_leave() Perl_pp_leave(aTHX)
-#define pp_leaveeval() Perl_pp_leaveeval(aTHX)
-#define pp_leavegiven() Perl_pp_leavegiven(aTHX)
-#define pp_leaveloop() Perl_pp_leaveloop(aTHX)
-#define pp_leavesub() Perl_pp_leavesub(aTHX)
-#define pp_leavesublv() Perl_pp_leavesublv(aTHX)
-#define pp_leavetry() Perl_pp_leavetry(aTHX)
-#define pp_leavewhen() Perl_pp_leavewhen(aTHX)
-#define pp_leavewrite() Perl_pp_leavewrite(aTHX)
-#define pp_left_shift() Perl_pp_left_shift(aTHX)
-#define pp_length() Perl_pp_length(aTHX)
-#define pp_lineseq() Perl_pp_lineseq(aTHX)
-#define pp_link() Perl_pp_link(aTHX)
-#define pp_list() Perl_pp_list(aTHX)
-#define pp_listen() Perl_pp_listen(aTHX)
-#define pp_localtime() Perl_pp_localtime(aTHX)
-#define pp_lock() Perl_pp_lock(aTHX)
-#define pp_log() Perl_pp_log(aTHX)
-#define pp_lslice() Perl_pp_lslice(aTHX)
-#define pp_lstat() Perl_pp_lstat(aTHX)
-#define pp_lt() Perl_pp_lt(aTHX)
-#define pp_mapstart() Perl_pp_mapstart(aTHX)
-#define pp_mapwhile() Perl_pp_mapwhile(aTHX)
-#define pp_match() Perl_pp_match(aTHX)
-#define pp_method() Perl_pp_method(aTHX)
-#define pp_method_named() Perl_pp_method_named(aTHX)
-#define pp_mkdir() Perl_pp_mkdir(aTHX)
-#define pp_modulo() Perl_pp_modulo(aTHX)
-#define pp_msgctl() Perl_pp_msgctl(aTHX)
-#define pp_msgget() Perl_pp_msgget(aTHX)
-#define pp_msgrcv() Perl_pp_msgrcv(aTHX)
-#define pp_msgsnd() Perl_pp_msgsnd(aTHX)
-#define pp_multiply() Perl_pp_multiply(aTHX)
-#define pp_ncmp() Perl_pp_ncmp(aTHX)
-#define pp_ne() Perl_pp_ne(aTHX)
-#define pp_negate() Perl_pp_negate(aTHX)
-#define pp_next() Perl_pp_next(aTHX)
-#define pp_nextstate() Perl_pp_nextstate(aTHX)
-#define pp_not() Perl_pp_not(aTHX)
-#define pp_null() Perl_pp_null(aTHX)
-#define pp_oct() Perl_pp_oct(aTHX)
-#define pp_once() Perl_pp_once(aTHX)
-#define pp_open() Perl_pp_open(aTHX)
-#define pp_open_dir() Perl_pp_open_dir(aTHX)
-#define pp_or() Perl_pp_or(aTHX)
-#define pp_orassign() Perl_pp_orassign(aTHX)
-#define pp_ord() Perl_pp_ord(aTHX)
-#define pp_pack() Perl_pp_pack(aTHX)
-#define pp_padany() Perl_pp_padany(aTHX)
-#define pp_padav() Perl_pp_padav(aTHX)
-#define pp_padhv() Perl_pp_padhv(aTHX)
-#define pp_padsv() Perl_pp_padsv(aTHX)
-#define pp_pipe_op() Perl_pp_pipe_op(aTHX)
-#define pp_pop() Perl_pp_pop(aTHX)
-#define pp_pos() Perl_pp_pos(aTHX)
-#define pp_postdec() Perl_pp_postdec(aTHX)
-#define pp_postinc() Perl_pp_postinc(aTHX)
-#define pp_pow() Perl_pp_pow(aTHX)
-#define pp_predec() Perl_pp_predec(aTHX)
-#define pp_preinc() Perl_pp_preinc(aTHX)
-#define pp_print() Perl_pp_print(aTHX)
-#define pp_prototype() Perl_pp_prototype(aTHX)
-#define pp_prtf() Perl_pp_prtf(aTHX)
-#define pp_push() Perl_pp_push(aTHX)
-#define pp_pushmark() Perl_pp_pushmark(aTHX)
-#define pp_pushre() Perl_pp_pushre(aTHX)
-#define pp_qr() Perl_pp_qr(aTHX)
-#define pp_quotemeta() Perl_pp_quotemeta(aTHX)
-#define pp_rand() Perl_pp_rand(aTHX)
-#define pp_range() Perl_pp_range(aTHX)
-#define pp_rcatline() Perl_pp_rcatline(aTHX)
-#define pp_reach() Perl_pp_reach(aTHX)
-#define pp_read() Perl_pp_read(aTHX)
-#define pp_readdir() Perl_pp_readdir(aTHX)
-#define pp_readline() Perl_pp_readline(aTHX)
-#define pp_readlink() Perl_pp_readlink(aTHX)
-#define pp_recv() Perl_pp_recv(aTHX)
-#define pp_redo() Perl_pp_redo(aTHX)
-#define pp_ref() Perl_pp_ref(aTHX)
-#define pp_refgen() Perl_pp_refgen(aTHX)
-#define pp_regcmaybe() Perl_pp_regcmaybe(aTHX)
-#define pp_regcomp() Perl_pp_regcomp(aTHX)
-#define pp_regcreset() Perl_pp_regcreset(aTHX)
-#define pp_rename() Perl_pp_rename(aTHX)
-#define pp_repeat() Perl_pp_repeat(aTHX)
-#define pp_require() Perl_pp_require(aTHX)
-#define pp_reset() Perl_pp_reset(aTHX)
-#define pp_return() Perl_pp_return(aTHX)
-#define pp_reverse() Perl_pp_reverse(aTHX)
-#define pp_rewinddir() Perl_pp_rewinddir(aTHX)
-#define pp_right_shift() Perl_pp_right_shift(aTHX)
-#define pp_rindex() Perl_pp_rindex(aTHX)
-#define pp_rkeys() Perl_pp_rkeys(aTHX)
-#define pp_rmdir() Perl_pp_rmdir(aTHX)
-#define pp_rv2av() Perl_pp_rv2av(aTHX)
-#define pp_rv2cv() Perl_pp_rv2cv(aTHX)
-#define pp_rv2gv() Perl_pp_rv2gv(aTHX)
-#define pp_rv2hv() Perl_pp_rv2hv(aTHX)
-#define pp_rv2sv() Perl_pp_rv2sv(aTHX)
-#define pp_rvalues() Perl_pp_rvalues(aTHX)
-#define pp_sassign() Perl_pp_sassign(aTHX)
-#define pp_say() Perl_pp_say(aTHX)
-#define pp_scalar() Perl_pp_scalar(aTHX)
-#define pp_schomp() Perl_pp_schomp(aTHX)
-#define pp_schop() Perl_pp_schop(aTHX)
-#define pp_scmp() Perl_pp_scmp(aTHX)
-#define pp_scope() Perl_pp_scope(aTHX)
-#define pp_seek() Perl_pp_seek(aTHX)
-#define pp_seekdir() Perl_pp_seekdir(aTHX)
-#define pp_select() Perl_pp_select(aTHX)
-#define pp_semctl() Perl_pp_semctl(aTHX)
-#define pp_semget() Perl_pp_semget(aTHX)
-#define pp_semop() Perl_pp_semop(aTHX)
-#define pp_send() Perl_pp_send(aTHX)
-#define pp_seq() Perl_pp_seq(aTHX)
-#define pp_setpgrp() Perl_pp_setpgrp(aTHX)
-#define pp_setpriority() Perl_pp_setpriority(aTHX)
-#define pp_sge() Perl_pp_sge(aTHX)
-#define pp_sgrent() Perl_pp_sgrent(aTHX)
-#define pp_sgt() Perl_pp_sgt(aTHX)
-#define pp_shift() Perl_pp_shift(aTHX)
-#define pp_shmctl() Perl_pp_shmctl(aTHX)
-#define pp_shmget() Perl_pp_shmget(aTHX)
-#define pp_shmread() Perl_pp_shmread(aTHX)
-#define pp_shmwrite() Perl_pp_shmwrite(aTHX)
-#define pp_shostent() Perl_pp_shostent(aTHX)
-#define pp_shutdown() Perl_pp_shutdown(aTHX)
-#define pp_sin() Perl_pp_sin(aTHX)
-#define pp_sle() Perl_pp_sle(aTHX)
-#define pp_sleep() Perl_pp_sleep(aTHX)
-#define pp_slt() Perl_pp_slt(aTHX)
-#define pp_smartmatch() Perl_pp_smartmatch(aTHX)
-#define pp_sne() Perl_pp_sne(aTHX)
-#define pp_snetent() Perl_pp_snetent(aTHX)
-#define pp_socket() Perl_pp_socket(aTHX)
-#define pp_sockpair() Perl_pp_sockpair(aTHX)
-#define pp_sort() Perl_pp_sort(aTHX)
-#define pp_splice() Perl_pp_splice(aTHX)
-#define pp_split() Perl_pp_split(aTHX)
-#define pp_sprintf() Perl_pp_sprintf(aTHX)
-#define pp_sprotoent() Perl_pp_sprotoent(aTHX)
-#define pp_spwent() Perl_pp_spwent(aTHX)
-#define pp_sqrt() Perl_pp_sqrt(aTHX)
-#define pp_srand() Perl_pp_srand(aTHX)
-#define pp_srefgen() Perl_pp_srefgen(aTHX)
-#define pp_sselect() Perl_pp_sselect(aTHX)
-#define pp_sservent() Perl_pp_sservent(aTHX)
-#define pp_ssockopt() Perl_pp_ssockopt(aTHX)
-#define pp_stat() Perl_pp_stat(aTHX)
-#define pp_stringify() Perl_pp_stringify(aTHX)
-#define pp_stub() Perl_pp_stub(aTHX)
-#define pp_study() Perl_pp_study(aTHX)
-#define pp_subst() Perl_pp_subst(aTHX)
-#define pp_substcont() Perl_pp_substcont(aTHX)
-#define pp_substr() Perl_pp_substr(aTHX)
-#define pp_subtract() Perl_pp_subtract(aTHX)
-#define pp_symlink() Perl_pp_symlink(aTHX)
-#define pp_syscall() Perl_pp_syscall(aTHX)
-#define pp_sysopen() Perl_pp_sysopen(aTHX)
-#define pp_sysread() Perl_pp_sysread(aTHX)
-#define pp_sysseek() Perl_pp_sysseek(aTHX)
-#define pp_system() Perl_pp_system(aTHX)
-#define pp_syswrite() Perl_pp_syswrite(aTHX)
-#define pp_tell() Perl_pp_tell(aTHX)
-#define pp_telldir() Perl_pp_telldir(aTHX)
-#define pp_tie() Perl_pp_tie(aTHX)
-#define pp_tied() Perl_pp_tied(aTHX)
-#define pp_time() Perl_pp_time(aTHX)
-#define pp_tms() Perl_pp_tms(aTHX)
-#define pp_trans() Perl_pp_trans(aTHX)
-#define pp_transr() Perl_pp_transr(aTHX)
-#define pp_truncate() Perl_pp_truncate(aTHX)
-#define pp_uc() Perl_pp_uc(aTHX)
-#define pp_ucfirst() Perl_pp_ucfirst(aTHX)
-#define pp_umask() Perl_pp_umask(aTHX)
-#define pp_undef() Perl_pp_undef(aTHX)
-#define pp_unlink() Perl_pp_unlink(aTHX)
-#define pp_unpack() Perl_pp_unpack(aTHX)
-#define pp_unshift() Perl_pp_unshift(aTHX)
-#define pp_unstack() Perl_pp_unstack(aTHX)
-#define pp_untie() Perl_pp_untie(aTHX)
-#define pp_utime() Perl_pp_utime(aTHX)
-#define pp_values() Perl_pp_values(aTHX)
-#define pp_vec() Perl_pp_vec(aTHX)
-#define pp_wait() Perl_pp_wait(aTHX)
-#define pp_waitpid() Perl_pp_waitpid(aTHX)
-#define pp_wantarray() Perl_pp_wantarray(aTHX)
-#define pp_warn() Perl_pp_warn(aTHX)
-#define pp_xor() Perl_pp_xor(aTHX)
#define refcounted_he_chain_2hv(a,b) Perl_refcounted_he_chain_2hv(aTHX_ a,b)
#define refcounted_he_fetch_pv(a,b,c,d) Perl_refcounted_he_fetch_pv(aTHX_ a,b,c,d)
#define refcounted_he_fetch_pvn(a,b,c,d,e) Perl_refcounted_he_fetch_pvn(aTHX_ a,b,c,d,e)
diff --git a/embedvar.h b/embedvar.h
index 65b38f0667..32bf5c9087 100644
--- a/embedvar.h
+++ b/embedvar.h
@@ -10,7 +10,7 @@
*
* !!!!!!! DO NOT EDIT THIS FILE !!!!!!!
* This file is built by regen/embed.pl from data in embed.fnc,
- * regen/embed.pl, pp.sym, intrpvar.h, and perlvars.h.
+ * regen/embed.pl, regen/opcodes intrpvar.h, and perlvars.h.
* Any changes made here will be lost!
*
* Edit those files and run 'make regen_headers' to effect changes.
diff --git a/global.sym b/global.sym
index cf19e6cf28..122682deb0 100644
--- a/global.sym
+++ b/global.sym
@@ -10,7 +10,7 @@
#
# !!!!!!! DO NOT EDIT THIS FILE !!!!!!!
# This file is built by regen/embed.pl from data in embed.fnc,
-# regen/embed.pl, pp.sym, intrpvar.h, and perlvars.h.
+# regen/embed.pl, regen/opcodes intrpvar.h, and perlvars.h.
# Any changes made here will be lost!
#
# Edit those files and run 'make regen_headers' to effect changes.
diff --git a/gv.c b/gv.c
index ecc23c3cfb..9b57364be5 100644
--- a/gv.c
+++ b/gv.c
@@ -2409,7 +2409,7 @@ Perl_amagic_call(pTHX_ SV *left, SV *right, int method, int flags)
if (PERLDB_SUB && PL_curstash != PL_debstash)
PL_op->op_private |= OPpENTERSUB_DB;
PUTBACK;
- pp_pushmark();
+ Perl_pp_pushmark(aTHX);
EXTEND(SP, notfound + 5);
PUSHs(lr>0? right: left);
diff --git a/op.c b/op.c
index 339418c726..018ea43d4b 100644
--- a/op.c
+++ b/op.c
@@ -2744,12 +2744,12 @@ S_gen_constant_list(pTHX_ register OP *o)
PL_op = curop = LINKLIST(o);
o->op_next = 0;
CALL_PEEP(curop);
- pp_pushmark();
+ Perl_pp_pushmark(aTHX);
CALLRUNOPS(aTHX);
PL_op = curop;
assert (!(curop->op_flags & OPf_SPECIAL));
assert(curop->op_type == OP_RANGE);
- pp_anonlist();
+ Perl_pp_anonlist(aTHX);
PL_tmps_floor = oldtmps_floor;
o->op_type = OP_RV2AV;
diff --git a/perlapi.c b/perlapi.c
index 232b94f548..fed683bb2f 100644
--- a/perlapi.c
+++ b/perlapi.c
@@ -10,7 +10,7 @@
*
* !!!!!!! DO NOT EDIT THIS FILE !!!!!!!
* This file is built by regen/embed.pl from data in embed.fnc,
- * regen/embed.pl, pp.sym, intrpvar.h, and perlvars.h.
+ * regen/embed.pl, regen/opcodes intrpvar.h, and perlvars.h.
* Any changes made here will be lost!
*
* Edit those files and run 'make regen_headers' to effect changes.
diff --git a/perlapi.h b/perlapi.h
index 1c64ec72c3..74c1aa6018 100644
--- a/perlapi.h
+++ b/perlapi.h
@@ -10,7 +10,7 @@
*
* !!!!!!! DO NOT EDIT THIS FILE !!!!!!!
* This file is built by regen/embed.pl from data in embed.fnc,
- * regen/embed.pl, pp.sym, intrpvar.h, and perlvars.h.
+ * regen/embed.pl, regen/opcodes intrpvar.h, and perlvars.h.
* Any changes made here will be lost!
*
* Edit those files and run 'make regen_headers' to effect changes.
diff --git a/pp.sym b/pp.sym
deleted file mode 100644
index 09a35fc22d..0000000000
--- a/pp.sym
+++ /dev/null
@@ -1,374 +0,0 @@
-# -*- buffer-read-only: t -*-
-#
-# !!!!!!! DO NOT EDIT THIS FILE !!!!!!!
-# This file is built by regen/opcode.pl from its data. Any changes made
-# here will be lost!
-#
-
-Perl_pp_null
-Perl_pp_stub
-Perl_pp_scalar
-Perl_pp_pushmark
-Perl_pp_wantarray
-Perl_pp_const
-Perl_pp_gvsv
-Perl_pp_gv
-Perl_pp_gelem
-Perl_pp_padsv
-Perl_pp_padav
-Perl_pp_padhv
-Perl_pp_padany
-Perl_pp_pushre
-Perl_pp_rv2gv
-Perl_pp_rv2sv
-Perl_pp_av2arylen
-Perl_pp_rv2cv
-Perl_pp_anoncode
-Perl_pp_prototype
-Perl_pp_refgen
-Perl_pp_srefgen
-Perl_pp_ref
-Perl_pp_bless
-Perl_pp_backtick
-Perl_pp_glob
-Perl_pp_readline
-Perl_pp_rcatline
-Perl_pp_regcmaybe
-Perl_pp_regcreset
-Perl_pp_regcomp
-Perl_pp_match
-Perl_pp_qr
-Perl_pp_subst
-Perl_pp_substcont
-Perl_pp_trans
-Perl_pp_sassign
-Perl_pp_aassign
-Perl_pp_chop
-Perl_pp_schop
-Perl_pp_chomp
-Perl_pp_schomp
-Perl_pp_defined
-Perl_pp_undef
-Perl_pp_study
-Perl_pp_pos
-Perl_pp_preinc
-Perl_pp_predec
-Perl_pp_postinc
-Perl_pp_postdec
-Perl_pp_pow
-Perl_pp_multiply
-Perl_pp_i_multiply
-Perl_pp_divide
-Perl_pp_i_divide
-Perl_pp_modulo
-Perl_pp_i_modulo
-Perl_pp_repeat
-Perl_pp_add
-Perl_pp_i_add
-Perl_pp_subtract
-Perl_pp_i_subtract
-Perl_pp_concat
-Perl_pp_stringify
-Perl_pp_left_shift
-Perl_pp_right_shift
-Perl_pp_lt
-Perl_pp_i_lt
-Perl_pp_gt
-Perl_pp_i_gt
-Perl_pp_le
-Perl_pp_i_le
-Perl_pp_ge
-Perl_pp_i_ge
-Perl_pp_eq
-Perl_pp_i_eq
-Perl_pp_ne
-Perl_pp_i_ne
-Perl_pp_ncmp
-Perl_pp_i_ncmp
-Perl_pp_slt
-Perl_pp_sgt
-Perl_pp_sle
-Perl_pp_sge
-Perl_pp_seq
-Perl_pp_sne
-Perl_pp_scmp
-Perl_pp_bit_and
-Perl_pp_bit_xor
-Perl_pp_bit_or
-Perl_pp_negate
-Perl_pp_i_negate
-Perl_pp_not
-Perl_pp_complement
-Perl_pp_smartmatch
-Perl_pp_atan2
-Perl_pp_sin
-Perl_pp_cos
-Perl_pp_rand
-Perl_pp_srand
-Perl_pp_exp
-Perl_pp_log
-Perl_pp_sqrt
-Perl_pp_int
-Perl_pp_hex
-Perl_pp_oct
-Perl_pp_abs
-Perl_pp_length
-Perl_pp_substr
-Perl_pp_vec
-Perl_pp_index
-Perl_pp_rindex
-Perl_pp_sprintf
-Perl_pp_formline
-Perl_pp_ord
-Perl_pp_chr
-Perl_pp_crypt
-Perl_pp_ucfirst
-Perl_pp_lcfirst
-Perl_pp_uc
-Perl_pp_lc
-Perl_pp_quotemeta
-Perl_pp_rv2av
-Perl_pp_aelemfast
-Perl_pp_aelem
-Perl_pp_aslice
-Perl_pp_aeach
-Perl_pp_akeys
-Perl_pp_avalues
-Perl_pp_each
-Perl_pp_values
-Perl_pp_keys
-Perl_pp_delete
-Perl_pp_exists
-Perl_pp_rv2hv
-Perl_pp_helem
-Perl_pp_hslice
-Perl_pp_boolkeys
-Perl_pp_unpack
-Perl_pp_pack
-Perl_pp_split
-Perl_pp_join
-Perl_pp_list
-Perl_pp_lslice
-Perl_pp_anonlist
-Perl_pp_anonhash
-Perl_pp_splice
-Perl_pp_push
-Perl_pp_pop
-Perl_pp_shift
-Perl_pp_unshift
-Perl_pp_sort
-Perl_pp_reverse
-Perl_pp_grepstart
-Perl_pp_grepwhile
-Perl_pp_mapstart
-Perl_pp_mapwhile
-Perl_pp_range
-Perl_pp_flip
-Perl_pp_flop
-Perl_pp_and
-Perl_pp_or
-Perl_pp_xor
-Perl_pp_dor
-Perl_pp_cond_expr
-Perl_pp_andassign
-Perl_pp_orassign
-Perl_pp_dorassign
-Perl_pp_method
-Perl_pp_entersub
-Perl_pp_leavesub
-Perl_pp_leavesublv
-Perl_pp_caller
-Perl_pp_warn
-Perl_pp_die
-Perl_pp_reset
-Perl_pp_lineseq
-Perl_pp_nextstate
-Perl_pp_dbstate
-Perl_pp_unstack
-Perl_pp_enter
-Perl_pp_leave
-Perl_pp_scope
-Perl_pp_enteriter
-Perl_pp_iter
-Perl_pp_enterloop
-Perl_pp_leaveloop
-Perl_pp_return
-Perl_pp_last
-Perl_pp_next
-Perl_pp_redo
-Perl_pp_dump
-Perl_pp_goto
-Perl_pp_exit
-Perl_pp_method_named
-Perl_pp_entergiven
-Perl_pp_leavegiven
-Perl_pp_enterwhen
-Perl_pp_leavewhen
-Perl_pp_break
-Perl_pp_continue
-Perl_pp_open
-Perl_pp_close
-Perl_pp_pipe_op
-Perl_pp_fileno
-Perl_pp_umask
-Perl_pp_binmode
-Perl_pp_tie
-Perl_pp_untie
-Perl_pp_tied
-Perl_pp_dbmopen
-Perl_pp_dbmclose
-Perl_pp_sselect
-Perl_pp_select
-Perl_pp_getc
-Perl_pp_read
-Perl_pp_enterwrite
-Perl_pp_leavewrite
-Perl_pp_prtf
-Perl_pp_print
-Perl_pp_say
-Perl_pp_sysopen
-Perl_pp_sysseek
-Perl_pp_sysread
-Perl_pp_syswrite
-Perl_pp_eof
-Perl_pp_tell
-Perl_pp_seek
-Perl_pp_truncate
-Perl_pp_fcntl
-Perl_pp_ioctl
-Perl_pp_flock
-Perl_pp_send
-Perl_pp_recv
-Perl_pp_socket
-Perl_pp_sockpair
-Perl_pp_bind
-Perl_pp_connect
-Perl_pp_listen
-Perl_pp_accept
-Perl_pp_shutdown
-Perl_pp_gsockopt
-Perl_pp_ssockopt
-Perl_pp_getsockname
-Perl_pp_getpeername
-Perl_pp_lstat
-Perl_pp_stat
-Perl_pp_ftrread
-Perl_pp_ftrwrite
-Perl_pp_ftrexec
-Perl_pp_fteread
-Perl_pp_ftewrite
-Perl_pp_fteexec
-Perl_pp_ftis
-Perl_pp_ftsize
-Perl_pp_ftmtime
-Perl_pp_ftatime
-Perl_pp_ftctime
-Perl_pp_ftrowned
-Perl_pp_fteowned
-Perl_pp_ftzero
-Perl_pp_ftsock
-Perl_pp_ftchr
-Perl_pp_ftblk
-Perl_pp_ftfile
-Perl_pp_ftdir
-Perl_pp_ftpipe
-Perl_pp_ftsuid
-Perl_pp_ftsgid
-Perl_pp_ftsvtx
-Perl_pp_ftlink
-Perl_pp_fttty
-Perl_pp_fttext
-Perl_pp_ftbinary
-Perl_pp_chdir
-Perl_pp_chown
-Perl_pp_chroot
-Perl_pp_unlink
-Perl_pp_chmod
-Perl_pp_utime
-Perl_pp_rename
-Perl_pp_link
-Perl_pp_symlink
-Perl_pp_readlink
-Perl_pp_mkdir
-Perl_pp_rmdir
-Perl_pp_open_dir
-Perl_pp_readdir
-Perl_pp_telldir
-Perl_pp_seekdir
-Perl_pp_rewinddir
-Perl_pp_closedir
-Perl_pp_fork
-Perl_pp_wait
-Perl_pp_waitpid
-Perl_pp_system
-Perl_pp_exec
-Perl_pp_kill
-Perl_pp_getppid
-Perl_pp_getpgrp
-Perl_pp_setpgrp
-Perl_pp_getpriority
-Perl_pp_setpriority
-Perl_pp_time
-Perl_pp_tms
-Perl_pp_localtime
-Perl_pp_gmtime
-Perl_pp_alarm
-Perl_pp_sleep
-Perl_pp_shmget
-Perl_pp_shmctl
-Perl_pp_shmread
-Perl_pp_shmwrite
-Perl_pp_msgget
-Perl_pp_msgctl
-Perl_pp_msgsnd
-Perl_pp_msgrcv
-Perl_pp_semop
-Perl_pp_semget
-Perl_pp_semctl
-Perl_pp_require
-Perl_pp_dofile
-Perl_pp_hintseval
-Perl_pp_entereval
-Perl_pp_leaveeval
-Perl_pp_entertry
-Perl_pp_leavetry
-Perl_pp_ghbyname
-Perl_pp_ghbyaddr
-Perl_pp_ghostent
-Perl_pp_gnbyname
-Perl_pp_gnbyaddr
-Perl_pp_gnetent
-Perl_pp_gpbyname
-Perl_pp_gpbynumber
-Perl_pp_gprotoent
-Perl_pp_gsbyname
-Perl_pp_gsbyport
-Perl_pp_gservent
-Perl_pp_shostent
-Perl_pp_snetent
-Perl_pp_sprotoent
-Perl_pp_sservent
-Perl_pp_ehostent
-Perl_pp_enetent
-Perl_pp_eprotoent
-Perl_pp_eservent
-Perl_pp_gpwnam
-Perl_pp_gpwuid
-Perl_pp_gpwent
-Perl_pp_spwent
-Perl_pp_epwent
-Perl_pp_ggrnam
-Perl_pp_ggrgid
-Perl_pp_ggrent
-Perl_pp_sgrent
-Perl_pp_egrent
-Perl_pp_getlogin
-Perl_pp_syscall
-Perl_pp_lock
-Perl_pp_once
-Perl_pp_reach
-Perl_pp_rkeys
-Perl_pp_rvalues
-Perl_pp_transr
-
-# ex: set ro:
diff --git a/pp_ctl.c b/pp_ctl.c
index 0ad47a6238..5a53565366 100644
--- a/pp_ctl.c
+++ b/pp_ctl.c
@@ -1039,8 +1039,8 @@ PP(pp_grepstart)
RETURNOP(PL_op->op_next->op_next);
}
PL_stack_sp = PL_stack_base + *PL_markstack_ptr + 1;
- pp_pushmark(); /* push dst */
- pp_pushmark(); /* push src */
+ Perl_pp_pushmark(aTHX); /* push dst */
+ Perl_pp_pushmark(aTHX); /* push src */
ENTER_with_name("grep"); /* enter outer scope */
SAVETMPS;
@@ -1060,7 +1060,7 @@ PP(pp_grepstart)
PUTBACK;
if (PL_op->op_type == OP_MAPSTART)
- pp_pushmark(); /* push top */
+ Perl_pp_pushmark(aTHX); /* push top */
return ((LOGOP*)PL_op->op_next)->op_other;
}
@@ -4275,7 +4275,7 @@ S_matcher_matches_sv(pTHX_ PMOP *matcher, SV *sv)
PL_op = (OP *) matcher;
XPUSHs(sv);
PUTBACK;
- (void) pp_match();
+ (void) Perl_pp_match(aTHX);
SPAGAIN;
return (SvTRUEx(POPs));
}
@@ -4758,9 +4758,9 @@ S_do_smartmatch(pTHX_ HV *seen_this, HV *seen_other)
PUSHs(d); PUSHs(e);
PUTBACK;
if (CopHINTS_get(PL_curcop) & HINT_INTEGER)
- (void) pp_i_eq();
+ (void) Perl_pp_i_eq(aTHX);
else
- (void) pp_eq();
+ (void) Perl_pp_eq(aTHX);
SPAGAIN;
if (SvTRUEx(POPs))
RETPUSHYES;
@@ -4772,7 +4772,7 @@ S_do_smartmatch(pTHX_ HV *seen_this, HV *seen_other)
DEBUG_M(Perl_deb(aTHX_ " applying rule Any-Any\n"));
PUSHs(d); PUSHs(e);
PUTBACK;
- return pp_seq();
+ return Perl_pp_seq(aTHX);
}
PP(pp_enterwhen)
diff --git a/pp_hot.c b/pp_hot.c
index e7cda17966..bd0402af99 100644
--- a/pp_hot.c
+++ b/pp_hot.c
@@ -324,7 +324,7 @@ PP(pp_readline)
dSP;
XPUSHs(MUTABLE_SV(PL_last_in_gv));
PUTBACK;
- pp_rv2gv();
+ Perl_pp_rv2gv(aTHX);
PL_last_in_gv = MUTABLE_GV(*PL_stack_sp--);
}
}
diff --git a/pp_proto.h b/pp_proto.h
index f0126bd578..5d7c76e263 100644
--- a/pp_proto.h
+++ b/pp_proto.h
@@ -1,2 +1,373 @@
-/* We can't remove this file until we remove the references to it in
- ExtUtils::MM_Unix.pm and ExtUtils::MM_VMS.pm */
+/* -*- buffer-read-only: t -*-
+ !!!!!!! DO NOT EDIT THIS FILE !!!!!!!
+ This file is built by opcode.pl from its data. Any changes made here
+ will be lost!
+*/
+
+PERL_CALLCONV OP *Perl_pp_aassign(pTHX);
+PERL_CALLCONV OP *Perl_pp_abs(pTHX);
+PERL_CALLCONV OP *Perl_pp_accept(pTHX);
+PERL_CALLCONV OP *Perl_pp_add(pTHX);
+PERL_CALLCONV OP *Perl_pp_aeach(pTHX);
+PERL_CALLCONV OP *Perl_pp_aelem(pTHX);
+PERL_CALLCONV OP *Perl_pp_aelemfast(pTHX);
+PERL_CALLCONV OP *Perl_pp_akeys(pTHX);
+PERL_CALLCONV OP *Perl_pp_alarm(pTHX);
+PERL_CALLCONV OP *Perl_pp_and(pTHX);
+PERL_CALLCONV OP *Perl_pp_andassign(pTHX);
+PERL_CALLCONV OP *Perl_pp_anoncode(pTHX);
+PERL_CALLCONV OP *Perl_pp_anonhash(pTHX);
+PERL_CALLCONV OP *Perl_pp_anonlist(pTHX);
+PERL_CALLCONV OP *Perl_pp_aslice(pTHX);
+PERL_CALLCONV OP *Perl_pp_atan2(pTHX);
+PERL_CALLCONV OP *Perl_pp_av2arylen(pTHX);
+PERL_CALLCONV OP *Perl_pp_avalues(pTHX);
+PERL_CALLCONV OP *Perl_pp_backtick(pTHX);
+PERL_CALLCONV OP *Perl_pp_bind(pTHX);
+PERL_CALLCONV OP *Perl_pp_binmode(pTHX);
+PERL_CALLCONV OP *Perl_pp_bit_and(pTHX);
+PERL_CALLCONV OP *Perl_pp_bit_or(pTHX);
+PERL_CALLCONV OP *Perl_pp_bit_xor(pTHX);
+PERL_CALLCONV OP *Perl_pp_bless(pTHX);
+PERL_CALLCONV OP *Perl_pp_boolkeys(pTHX);
+PERL_CALLCONV OP *Perl_pp_break(pTHX);
+PERL_CALLCONV OP *Perl_pp_caller(pTHX);
+PERL_CALLCONV OP *Perl_pp_chdir(pTHX);
+PERL_CALLCONV OP *Perl_pp_chmod(pTHX);
+PERL_CALLCONV OP *Perl_pp_chomp(pTHX);
+PERL_CALLCONV OP *Perl_pp_chop(pTHX);
+PERL_CALLCONV OP *Perl_pp_chown(pTHX);
+PERL_CALLCONV OP *Perl_pp_chr(pTHX);
+PERL_CALLCONV OP *Perl_pp_chroot(pTHX);
+PERL_CALLCONV OP *Perl_pp_close(pTHX);
+PERL_CALLCONV OP *Perl_pp_closedir(pTHX);
+PERL_CALLCONV OP *Perl_pp_complement(pTHX);
+PERL_CALLCONV OP *Perl_pp_concat(pTHX);
+PERL_CALLCONV OP *Perl_pp_cond_expr(pTHX);
+PERL_CALLCONV OP *Perl_pp_connect(pTHX);
+PERL_CALLCONV OP *Perl_pp_const(pTHX);
+PERL_CALLCONV OP *Perl_pp_continue(pTHX);
+PERL_CALLCONV OP *Perl_pp_cos(pTHX);
+PERL_CALLCONV OP *Perl_pp_crypt(pTHX);
+PERL_CALLCONV OP *Perl_pp_dbmclose(pTHX);
+PERL_CALLCONV OP *Perl_pp_dbmopen(pTHX);
+PERL_CALLCONV OP *Perl_pp_dbstate(pTHX);
+PERL_CALLCONV OP *Perl_pp_defined(pTHX);
+PERL_CALLCONV OP *Perl_pp_delete(pTHX);
+PERL_CALLCONV OP *Perl_pp_die(pTHX);
+PERL_CALLCONV OP *Perl_pp_divide(pTHX);
+PERL_CALLCONV OP *Perl_pp_dofile(pTHX);
+PERL_CALLCONV OP *Perl_pp_dor(pTHX);
+PERL_CALLCONV OP *Perl_pp_dorassign(pTHX);
+PERL_CALLCONV OP *Perl_pp_dump(pTHX);
+PERL_CALLCONV OP *Perl_pp_each(pTHX);
+PERL_CALLCONV OP *Perl_pp_egrent(pTHX);
+PERL_CALLCONV OP *Perl_pp_ehostent(pTHX);
+PERL_CALLCONV OP *Perl_pp_enetent(pTHX);
+PERL_CALLCONV OP *Perl_pp_enter(pTHX);
+PERL_CALLCONV OP *Perl_pp_entereval(pTHX);
+PERL_CALLCONV OP *Perl_pp_entergiven(pTHX);
+PERL_CALLCONV OP *Perl_pp_enteriter(pTHX);
+PERL_CALLCONV OP *Perl_pp_enterloop(pTHX);
+PERL_CALLCONV OP *Perl_pp_entersub(pTHX);
+PERL_CALLCONV OP *Perl_pp_entertry(pTHX);
+PERL_CALLCONV OP *Perl_pp_enterwhen(pTHX);
+PERL_CALLCONV OP *Perl_pp_enterwrite(pTHX);
+PERL_CALLCONV OP *Perl_pp_eof(pTHX);
+PERL_CALLCONV OP *Perl_pp_eprotoent(pTHX);
+PERL_CALLCONV OP *Perl_pp_epwent(pTHX);
+PERL_CALLCONV OP *Perl_pp_eq(pTHX);
+PERL_CALLCONV OP *Perl_pp_eservent(pTHX);
+PERL_CALLCONV OP *Perl_pp_exec(pTHX);
+PERL_CALLCONV OP *Perl_pp_exists(pTHX);
+PERL_CALLCONV OP *Perl_pp_exit(pTHX);
+PERL_CALLCONV OP *Perl_pp_exp(pTHX);
+PERL_CALLCONV OP *Perl_pp_fcntl(pTHX);
+PERL_CALLCONV OP *Perl_pp_fileno(pTHX);
+PERL_CALLCONV OP *Perl_pp_flip(pTHX);
+PERL_CALLCONV OP *Perl_pp_flock(pTHX);
+PERL_CALLCONV OP *Perl_pp_flop(pTHX);
+PERL_CALLCONV OP *Perl_pp_fork(pTHX);
+PERL_CALLCONV OP *Perl_pp_formline(pTHX);
+PERL_CALLCONV OP *Perl_pp_ftatime(pTHX);
+PERL_CALLCONV OP *Perl_pp_ftbinary(pTHX);
+PERL_CALLCONV OP *Perl_pp_ftblk(pTHX);
+PERL_CALLCONV OP *Perl_pp_ftchr(pTHX);
+PERL_CALLCONV OP *Perl_pp_ftctime(pTHX);
+PERL_CALLCONV OP *Perl_pp_ftdir(pTHX);
+PERL_CALLCONV OP *Perl_pp_fteexec(pTHX);
+PERL_CALLCONV OP *Perl_pp_fteowned(pTHX);
+PERL_CALLCONV OP *Perl_pp_fteread(pTHX);
+PERL_CALLCONV OP *Perl_pp_ftewrite(pTHX);
+PERL_CALLCONV OP *Perl_pp_ftfile(pTHX);
+PERL_CALLCONV OP *Perl_pp_ftis(pTHX);
+PERL_CALLCONV OP *Perl_pp_ftlink(pTHX);
+PERL_CALLCONV OP *Perl_pp_ftmtime(pTHX);
+PERL_CALLCONV OP *Perl_pp_ftpipe(pTHX);
+PERL_CALLCONV OP *Perl_pp_ftrexec(pTHX);
+PERL_CALLCONV OP *Perl_pp_ftrowned(pTHX);
+PERL_CALLCONV OP *Perl_pp_ftrread(pTHX);
+PERL_CALLCONV OP *Perl_pp_ftrwrite(pTHX);
+PERL_CALLCONV OP *Perl_pp_ftsgid(pTHX);
+PERL_CALLCONV OP *Perl_pp_ftsize(pTHX);
+PERL_CALLCONV OP *Perl_pp_ftsock(pTHX);
+PERL_CALLCONV OP *Perl_pp_ftsuid(pTHX);
+PERL_CALLCONV OP *Perl_pp_ftsvtx(pTHX);
+PERL_CALLCONV OP *Perl_pp_fttext(pTHX);
+PERL_CALLCONV OP *Perl_pp_fttty(pTHX);
+PERL_CALLCONV OP *Perl_pp_ftzero(pTHX);
+PERL_CALLCONV OP *Perl_pp_ge(pTHX);
+PERL_CALLCONV OP *Perl_pp_gelem(pTHX);
+PERL_CALLCONV OP *Perl_pp_getc(pTHX);
+PERL_CALLCONV OP *Perl_pp_getlogin(pTHX);
+PERL_CALLCONV OP *Perl_pp_getpeername(pTHX);
+PERL_CALLCONV OP *Perl_pp_getpgrp(pTHX);
+PERL_CALLCONV OP *Perl_pp_getppid(pTHX);
+PERL_CALLCONV OP *Perl_pp_getpriority(pTHX);
+PERL_CALLCONV OP *Perl_pp_getsockname(pTHX);
+PERL_CALLCONV OP *Perl_pp_ggrent(pTHX);
+PERL_CALLCONV OP *Perl_pp_ggrgid(pTHX);
+PERL_CALLCONV OP *Perl_pp_ggrnam(pTHX);
+PERL_CALLCONV OP *Perl_pp_ghbyaddr(pTHX);
+PERL_CALLCONV OP *Perl_pp_ghbyname(pTHX);
+PERL_CALLCONV OP *Perl_pp_ghostent(pTHX);
+PERL_CALLCONV OP *Perl_pp_glob(pTHX);
+PERL_CALLCONV OP *Perl_pp_gmtime(pTHX);
+PERL_CALLCONV OP *Perl_pp_gnbyaddr(pTHX);
+PERL_CALLCONV OP *Perl_pp_gnbyname(pTHX);
+PERL_CALLCONV OP *Perl_pp_gnetent(pTHX);
+PERL_CALLCONV OP *Perl_pp_goto(pTHX);
+PERL_CALLCONV OP *Perl_pp_gpbyname(pTHX);
+PERL_CALLCONV OP *Perl_pp_gpbynumber(pTHX);
+PERL_CALLCONV OP *Perl_pp_gprotoent(pTHX);
+PERL_CALLCONV OP *Perl_pp_gpwent(pTHX);
+PERL_CALLCONV OP *Perl_pp_gpwnam(pTHX);
+PERL_CALLCONV OP *Perl_pp_gpwuid(pTHX);
+PERL_CALLCONV OP *Perl_pp_grepstart(pTHX);
+PERL_CALLCONV OP *Perl_pp_grepwhile(pTHX);
+PERL_CALLCONV OP *Perl_pp_gsbyname(pTHX);
+PERL_CALLCONV OP *Perl_pp_gsbyport(pTHX);
+PERL_CALLCONV OP *Perl_pp_gservent(pTHX);
+PERL_CALLCONV OP *Perl_pp_gsockopt(pTHX);
+PERL_CALLCONV OP *Perl_pp_gt(pTHX);
+PERL_CALLCONV OP *Perl_pp_gv(pTHX);
+PERL_CALLCONV OP *Perl_pp_gvsv(pTHX);
+PERL_CALLCONV OP *Perl_pp_helem(pTHX);
+PERL_CALLCONV OP *Perl_pp_hex(pTHX);
+PERL_CALLCONV OP *Perl_pp_hintseval(pTHX);
+PERL_CALLCONV OP *Perl_pp_hslice(pTHX);
+PERL_CALLCONV OP *Perl_pp_i_add(pTHX);
+PERL_CALLCONV OP *Perl_pp_i_divide(pTHX);
+PERL_CALLCONV OP *Perl_pp_i_eq(pTHX);
+PERL_CALLCONV OP *Perl_pp_i_ge(pTHX);
+PERL_CALLCONV OP *Perl_pp_i_gt(pTHX);
+PERL_CALLCONV OP *Perl_pp_i_le(pTHX);
+PERL_CALLCONV OP *Perl_pp_i_lt(pTHX);
+PERL_CALLCONV OP *Perl_pp_i_modulo(pTHX);
+PERL_CALLCONV OP *Perl_pp_i_multiply(pTHX);
+PERL_CALLCONV OP *Perl_pp_i_ncmp(pTHX);
+PERL_CALLCONV OP *Perl_pp_i_ne(pTHX);
+PERL_CALLCONV OP *Perl_pp_i_negate(pTHX);
+PERL_CALLCONV OP *Perl_pp_i_subtract(pTHX);
+PERL_CALLCONV OP *Perl_pp_index(pTHX);
+PERL_CALLCONV OP *Perl_pp_int(pTHX);
+PERL_CALLCONV OP *Perl_pp_ioctl(pTHX);
+PERL_CALLCONV OP *Perl_pp_iter(pTHX);
+PERL_CALLCONV OP *Perl_pp_join(pTHX);
+PERL_CALLCONV OP *Perl_pp_keys(pTHX);
+PERL_CALLCONV OP *Perl_pp_kill(pTHX);
+PERL_CALLCONV OP *Perl_pp_last(pTHX);
+PERL_CALLCONV OP *Perl_pp_lc(pTHX);
+PERL_CALLCONV OP *Perl_pp_lcfirst(pTHX);
+PERL_CALLCONV OP *Perl_pp_le(pTHX);
+PERL_CALLCONV OP *Perl_pp_leave(pTHX);
+PERL_CALLCONV OP *Perl_pp_leaveeval(pTHX);
+PERL_CALLCONV OP *Perl_pp_leavegiven(pTHX);
+PERL_CALLCONV OP *Perl_pp_leaveloop(pTHX);
+PERL_CALLCONV OP *Perl_pp_leavesub(pTHX);
+PERL_CALLCONV OP *Perl_pp_leavesublv(pTHX);
+PERL_CALLCONV OP *Perl_pp_leavetry(pTHX);
+PERL_CALLCONV OP *Perl_pp_leavewhen(pTHX);
+PERL_CALLCONV OP *Perl_pp_leavewrite(pTHX);
+PERL_CALLCONV OP *Perl_pp_left_shift(pTHX);
+PERL_CALLCONV OP *Perl_pp_length(pTHX);
+PERL_CALLCONV OP *Perl_pp_lineseq(pTHX);
+PERL_CALLCONV OP *Perl_pp_link(pTHX);
+PERL_CALLCONV OP *Perl_pp_list(pTHX);
+PERL_CALLCONV OP *Perl_pp_listen(pTHX);
+PERL_CALLCONV OP *Perl_pp_localtime(pTHX);
+PERL_CALLCONV OP *Perl_pp_lock(pTHX);
+PERL_CALLCONV OP *Perl_pp_log(pTHX);
+PERL_CALLCONV OP *Perl_pp_lslice(pTHX);
+PERL_CALLCONV OP *Perl_pp_lstat(pTHX);
+PERL_CALLCONV OP *Perl_pp_lt(pTHX);
+PERL_CALLCONV OP *Perl_pp_mapstart(pTHX);
+PERL_CALLCONV OP *Perl_pp_mapwhile(pTHX);
+PERL_CALLCONV OP *Perl_pp_match(pTHX);
+PERL_CALLCONV OP *Perl_pp_method(pTHX);
+PERL_CALLCONV OP *Perl_pp_method_named(pTHX);
+PERL_CALLCONV OP *Perl_pp_mkdir(pTHX);
+PERL_CALLCONV OP *Perl_pp_modulo(pTHX);
+PERL_CALLCONV OP *Perl_pp_msgctl(pTHX);
+PERL_CALLCONV OP *Perl_pp_msgget(pTHX);
+PERL_CALLCONV OP *Perl_pp_msgrcv(pTHX);
+PERL_CALLCONV OP *Perl_pp_msgsnd(pTHX);
+PERL_CALLCONV OP *Perl_pp_multiply(pTHX);
+PERL_CALLCONV OP *Perl_pp_ncmp(pTHX);
+PERL_CALLCONV OP *Perl_pp_ne(pTHX);
+PERL_CALLCONV OP *Perl_pp_negate(pTHX);
+PERL_CALLCONV OP *Perl_pp_next(pTHX);
+PERL_CALLCONV OP *Perl_pp_nextstate(pTHX);
+PERL_CALLCONV OP *Perl_pp_not(pTHX);
+PERL_CALLCONV OP *Perl_pp_null(pTHX);
+PERL_CALLCONV OP *Perl_pp_oct(pTHX);
+PERL_CALLCONV OP *Perl_pp_once(pTHX);
+PERL_CALLCONV OP *Perl_pp_open(pTHX);
+PERL_CALLCONV OP *Perl_pp_open_dir(pTHX);
+PERL_CALLCONV OP *Perl_pp_or(pTHX);
+PERL_CALLCONV OP *Perl_pp_orassign(pTHX);
+PERL_CALLCONV OP *Perl_pp_ord(pTHX);
+PERL_CALLCONV OP *Perl_pp_pack(pTHX);
+PERL_CALLCONV OP *Perl_pp_padany(pTHX);
+PERL_CALLCONV OP *Perl_pp_padav(pTHX);
+PERL_CALLCONV OP *Perl_pp_padhv(pTHX);
+PERL_CALLCONV OP *Perl_pp_padsv(pTHX);
+PERL_CALLCONV OP *Perl_pp_pipe_op(pTHX);
+PERL_CALLCONV OP *Perl_pp_pop(pTHX);
+PERL_CALLCONV OP *Perl_pp_pos(pTHX);
+PERL_CALLCONV OP *Perl_pp_postdec(pTHX);
+PERL_CALLCONV OP *Perl_pp_postinc(pTHX);
+PERL_CALLCONV OP *Perl_pp_pow(pTHX);
+PERL_CALLCONV OP *Perl_pp_predec(pTHX);
+PERL_CALLCONV OP *Perl_pp_preinc(pTHX);
+PERL_CALLCONV OP *Perl_pp_print(pTHX);
+PERL_CALLCONV OP *Perl_pp_prototype(pTHX);
+PERL_CALLCONV OP *Perl_pp_prtf(pTHX);
+PERL_CALLCONV OP *Perl_pp_push(pTHX);
+PERL_CALLCONV OP *Perl_pp_pushmark(pTHX);
+PERL_CALLCONV OP *Perl_pp_pushre(pTHX);
+PERL_CALLCONV OP *Perl_pp_qr(pTHX);
+PERL_CALLCONV OP *Perl_pp_quotemeta(pTHX);
+PERL_CALLCONV OP *Perl_pp_rand(pTHX);
+PERL_CALLCONV OP *Perl_pp_range(pTHX);
+PERL_CALLCONV OP *Perl_pp_rcatline(pTHX);
+PERL_CALLCONV OP *Perl_pp_reach(pTHX);
+PERL_CALLCONV OP *Perl_pp_read(pTHX);
+PERL_CALLCONV OP *Perl_pp_readdir(pTHX);
+PERL_CALLCONV OP *Perl_pp_readline(pTHX);
+PERL_CALLCONV OP *Perl_pp_readlink(pTHX);
+PERL_CALLCONV OP *Perl_pp_recv(pTHX);
+PERL_CALLCONV OP *Perl_pp_redo(pTHX);
+PERL_CALLCONV OP *Perl_pp_ref(pTHX);
+PERL_CALLCONV OP *Perl_pp_refgen(pTHX);
+PERL_CALLCONV OP *Perl_pp_regcmaybe(pTHX);
+PERL_CALLCONV OP *Perl_pp_regcomp(pTHX);
+PERL_CALLCONV OP *Perl_pp_regcreset(pTHX);
+PERL_CALLCONV OP *Perl_pp_rename(pTHX);
+PERL_CALLCONV OP *Perl_pp_repeat(pTHX);
+PERL_CALLCONV OP *Perl_pp_require(pTHX);
+PERL_CALLCONV OP *Perl_pp_reset(pTHX);
+PERL_CALLCONV OP *Perl_pp_return(pTHX);
+PERL_CALLCONV OP *Perl_pp_reverse(pTHX);
+PERL_CALLCONV OP *Perl_pp_rewinddir(pTHX);
+PERL_CALLCONV OP *Perl_pp_right_shift(pTHX);
+PERL_CALLCONV OP *Perl_pp_rindex(pTHX);
+PERL_CALLCONV OP *Perl_pp_rkeys(pTHX);
+PERL_CALLCONV OP *Perl_pp_rmdir(pTHX);
+PERL_CALLCONV OP *Perl_pp_rv2av(pTHX);
+PERL_CALLCONV OP *Perl_pp_rv2cv(pTHX);
+PERL_CALLCONV OP *Perl_pp_rv2gv(pTHX);
+PERL_CALLCONV OP *Perl_pp_rv2hv(pTHX);
+PERL_CALLCONV OP *Perl_pp_rv2sv(pTHX);
+PERL_CALLCONV OP *Perl_pp_rvalues(pTHX);
+PERL_CALLCONV OP *Perl_pp_sassign(pTHX);
+PERL_CALLCONV OP *Perl_pp_say(pTHX);
+PERL_CALLCONV OP *Perl_pp_scalar(pTHX);
+PERL_CALLCONV OP *Perl_pp_schomp(pTHX);
+PERL_CALLCONV OP *Perl_pp_schop(pTHX);
+PERL_CALLCONV OP *Perl_pp_scmp(pTHX);
+PERL_CALLCONV OP *Perl_pp_scope(pTHX);
+PERL_CALLCONV OP *Perl_pp_seek(pTHX);
+PERL_CALLCONV OP *Perl_pp_seekdir(pTHX);
+PERL_CALLCONV OP *Perl_pp_select(pTHX);
+PERL_CALLCONV OP *Perl_pp_semctl(pTHX);
+PERL_CALLCONV OP *Perl_pp_semget(pTHX);
+PERL_CALLCONV OP *Perl_pp_semop(pTHX);
+PERL_CALLCONV OP *Perl_pp_send(pTHX);
+PERL_CALLCONV OP *Perl_pp_seq(pTHX);
+PERL_CALLCONV OP *Perl_pp_setpgrp(pTHX);
+PERL_CALLCONV OP *Perl_pp_setpriority(pTHX);
+PERL_CALLCONV OP *Perl_pp_sge(pTHX);
+PERL_CALLCONV OP *Perl_pp_sgrent(pTHX);
+PERL_CALLCONV OP *Perl_pp_sgt(pTHX);
+PERL_CALLCONV OP *Perl_pp_shift(pTHX);
+PERL_CALLCONV OP *Perl_pp_shmctl(pTHX);
+PERL_CALLCONV OP *Perl_pp_shmget(pTHX);
+PERL_CALLCONV OP *Perl_pp_shmread(pTHX);
+PERL_CALLCONV OP *Perl_pp_shmwrite(pTHX);
+PERL_CALLCONV OP *Perl_pp_shostent(pTHX);
+PERL_CALLCONV OP *Perl_pp_shutdown(pTHX);
+PERL_CALLCONV OP *Perl_pp_sin(pTHX);
+PERL_CALLCONV OP *Perl_pp_sle(pTHX);
+PERL_CALLCONV OP *Perl_pp_sleep(pTHX);
+PERL_CALLCONV OP *Perl_pp_slt(pTHX);
+PERL_CALLCONV OP *Perl_pp_smartmatch(pTHX);
+PERL_CALLCONV OP *Perl_pp_sne(pTHX);
+PERL_CALLCONV OP *Perl_pp_snetent(pTHX);
+PERL_CALLCONV OP *Perl_pp_socket(pTHX);
+PERL_CALLCONV OP *Perl_pp_sockpair(pTHX);
+PERL_CALLCONV OP *Perl_pp_sort(pTHX);
+PERL_CALLCONV OP *Perl_pp_splice(pTHX);
+PERL_CALLCONV OP *Perl_pp_split(pTHX);
+PERL_CALLCONV OP *Perl_pp_sprintf(pTHX);
+PERL_CALLCONV OP *Perl_pp_sprotoent(pTHX);
+PERL_CALLCONV OP *Perl_pp_spwent(pTHX);
+PERL_CALLCONV OP *Perl_pp_sqrt(pTHX);
+PERL_CALLCONV OP *Perl_pp_srand(pTHX);
+PERL_CALLCONV OP *Perl_pp_srefgen(pTHX);
+PERL_CALLCONV OP *Perl_pp_sselect(pTHX);
+PERL_CALLCONV OP *Perl_pp_sservent(pTHX);
+PERL_CALLCONV OP *Perl_pp_ssockopt(pTHX);
+PERL_CALLCONV OP *Perl_pp_stat(pTHX);
+PERL_CALLCONV OP *Perl_pp_stringify(pTHX);
+PERL_CALLCONV OP *Perl_pp_stub(pTHX);
+PERL_CALLCONV OP *Perl_pp_study(pTHX);
+PERL_CALLCONV OP *Perl_pp_subst(pTHX);
+PERL_CALLCONV OP *Perl_pp_substcont(pTHX);
+PERL_CALLCONV OP *Perl_pp_substr(pTHX);
+PERL_CALLCONV OP *Perl_pp_subtract(pTHX);
+PERL_CALLCONV OP *Perl_pp_symlink(pTHX);
+PERL_CALLCONV OP *Perl_pp_syscall(pTHX);
+PERL_CALLCONV OP *Perl_pp_sysopen(pTHX);
+PERL_CALLCONV OP *Perl_pp_sysread(pTHX);
+PERL_CALLCONV OP *Perl_pp_sysseek(pTHX);
+PERL_CALLCONV OP *Perl_pp_system(pTHX);
+PERL_CALLCONV OP *Perl_pp_syswrite(pTHX);
+PERL_CALLCONV OP *Perl_pp_tell(pTHX);
+PERL_CALLCONV OP *Perl_pp_telldir(pTHX);
+PERL_CALLCONV OP *Perl_pp_tie(pTHX);
+PERL_CALLCONV OP *Perl_pp_tied(pTHX);
+PERL_CALLCONV OP *Perl_pp_time(pTHX);
+PERL_CALLCONV OP *Perl_pp_tms(pTHX);
+PERL_CALLCONV OP *Perl_pp_trans(pTHX);
+PERL_CALLCONV OP *Perl_pp_transr(pTHX);
+PERL_CALLCONV OP *Perl_pp_truncate(pTHX);
+PERL_CALLCONV OP *Perl_pp_uc(pTHX);
+PERL_CALLCONV OP *Perl_pp_ucfirst(pTHX);
+PERL_CALLCONV OP *Perl_pp_umask(pTHX);
+PERL_CALLCONV OP *Perl_pp_undef(pTHX);
+PERL_CALLCONV OP *Perl_pp_unlink(pTHX);
+PERL_CALLCONV OP *Perl_pp_unpack(pTHX);
+PERL_CALLCONV OP *Perl_pp_unshift(pTHX);
+PERL_CALLCONV OP *Perl_pp_unstack(pTHX);
+PERL_CALLCONV OP *Perl_pp_untie(pTHX);
+PERL_CALLCONV OP *Perl_pp_utime(pTHX);
+PERL_CALLCONV OP *Perl_pp_values(pTHX);
+PERL_CALLCONV OP *Perl_pp_vec(pTHX);
+PERL_CALLCONV OP *Perl_pp_wait(pTHX);
+PERL_CALLCONV OP *Perl_pp_waitpid(pTHX);
+PERL_CALLCONV OP *Perl_pp_wantarray(pTHX);
+PERL_CALLCONV OP *Perl_pp_warn(pTHX);
+PERL_CALLCONV OP *Perl_pp_xor(pTHX);
+
+/* ex: set ro: */
diff --git a/pp_sys.c b/pp_sys.c
index d8b31766d3..d6fd168087 100644
--- a/pp_sys.c
+++ b/pp_sys.c
@@ -4644,7 +4644,7 @@ PP(pp_shmwrite)
PUSHi(value);
RETURN;
#else
- return pp_semget();
+ return Perl_pp_semget(aTHX);
#endif
}
@@ -4681,7 +4681,7 @@ PP(pp_semctl)
}
RETURN;
#else
- return pp_semget();
+ return Perl_pp_semget(aTHX);
#endif
}
diff --git a/proto.h b/proto.h
index 5667a5e9ce..10016a99f5 100644
--- a/proto.h
+++ b/proto.h
@@ -10,7 +10,7 @@
*
* !!!!!!! DO NOT EDIT THIS FILE !!!!!!!
* This file is built by regen/embed.pl from data in embed.fnc,
- * regen/embed.pl, pp.sym, intrpvar.h, and perlvars.h.
+ * regen/embed.pl, regen/opcodes intrpvar.h, and perlvars.h.
* Any changes made here will be lost!
*
* Edit those files and run 'make regen_headers' to effect changes.
@@ -2866,371 +2866,6 @@ PERL_CALLCONV void Perl_populate_isa(pTHX_ const char *name, STRLEN len, ...)
#define PERL_ARGS_ASSERT_POPULATE_ISA \
assert(name)
-PERL_CALLCONV OP * Perl_pp_aassign(pTHX);
-PERL_CALLCONV OP * Perl_pp_abs(pTHX);
-PERL_CALLCONV OP * Perl_pp_accept(pTHX);
-PERL_CALLCONV OP * Perl_pp_add(pTHX);
-PERL_CALLCONV OP * Perl_pp_aeach(pTHX);
-PERL_CALLCONV OP * Perl_pp_aelem(pTHX);
-PERL_CALLCONV OP * Perl_pp_aelemfast(pTHX);
-PERL_CALLCONV OP * Perl_pp_akeys(pTHX);
-PERL_CALLCONV OP * Perl_pp_alarm(pTHX);
-PERL_CALLCONV OP * Perl_pp_and(pTHX);
-PERL_CALLCONV OP * Perl_pp_andassign(pTHX);
-PERL_CALLCONV OP * Perl_pp_anoncode(pTHX);
-PERL_CALLCONV OP * Perl_pp_anonhash(pTHX);
-PERL_CALLCONV OP * Perl_pp_anonlist(pTHX);
-PERL_CALLCONV OP * Perl_pp_aslice(pTHX);
-PERL_CALLCONV OP * Perl_pp_atan2(pTHX);
-PERL_CALLCONV OP * Perl_pp_av2arylen(pTHX);
-PERL_CALLCONV OP * Perl_pp_avalues(pTHX);
-PERL_CALLCONV OP * Perl_pp_backtick(pTHX);
-PERL_CALLCONV OP * Perl_pp_bind(pTHX);
-PERL_CALLCONV OP * Perl_pp_binmode(pTHX);
-PERL_CALLCONV OP * Perl_pp_bit_and(pTHX);
-PERL_CALLCONV OP * Perl_pp_bit_or(pTHX);
-PERL_CALLCONV OP * Perl_pp_bit_xor(pTHX);
-PERL_CALLCONV OP * Perl_pp_bless(pTHX);
-PERL_CALLCONV OP * Perl_pp_boolkeys(pTHX);
-PERL_CALLCONV OP * Perl_pp_break(pTHX);
-PERL_CALLCONV OP * Perl_pp_caller(pTHX);
-PERL_CALLCONV OP * Perl_pp_chdir(pTHX);
-PERL_CALLCONV OP * Perl_pp_chmod(pTHX);
-PERL_CALLCONV OP * Perl_pp_chomp(pTHX);
-PERL_CALLCONV OP * Perl_pp_chop(pTHX);
-PERL_CALLCONV OP * Perl_pp_chown(pTHX);
-PERL_CALLCONV OP * Perl_pp_chr(pTHX);
-PERL_CALLCONV OP * Perl_pp_chroot(pTHX);
-PERL_CALLCONV OP * Perl_pp_close(pTHX);
-PERL_CALLCONV OP * Perl_pp_closedir(pTHX);
-PERL_CALLCONV OP * Perl_pp_complement(pTHX);
-PERL_CALLCONV OP * Perl_pp_concat(pTHX);
-PERL_CALLCONV OP * Perl_pp_cond_expr(pTHX);
-PERL_CALLCONV OP * Perl_pp_connect(pTHX);
-PERL_CALLCONV OP * Perl_pp_const(pTHX);
-PERL_CALLCONV OP * Perl_pp_continue(pTHX);
-PERL_CALLCONV OP * Perl_pp_cos(pTHX);
-PERL_CALLCONV OP * Perl_pp_crypt(pTHX);
-PERL_CALLCONV OP * Perl_pp_dbmclose(pTHX);
-PERL_CALLCONV OP * Perl_pp_dbmopen(pTHX);
-PERL_CALLCONV OP * Perl_pp_dbstate(pTHX);
-PERL_CALLCONV OP * Perl_pp_defined(pTHX);
-PERL_CALLCONV OP * Perl_pp_delete(pTHX);
-PERL_CALLCONV OP * Perl_pp_die(pTHX);
-PERL_CALLCONV OP * Perl_pp_divide(pTHX);
-PERL_CALLCONV OP * Perl_pp_dofile(pTHX);
-PERL_CALLCONV OP * Perl_pp_dor(pTHX);
-PERL_CALLCONV OP * Perl_pp_dorassign(pTHX);
-PERL_CALLCONV OP * Perl_pp_dump(pTHX);
-PERL_CALLCONV OP * Perl_pp_each(pTHX);
-PERL_CALLCONV OP * Perl_pp_egrent(pTHX);
-PERL_CALLCONV OP * Perl_pp_ehostent(pTHX);
-PERL_CALLCONV OP * Perl_pp_enetent(pTHX);
-PERL_CALLCONV OP * Perl_pp_enter(pTHX);
-PERL_CALLCONV OP * Perl_pp_entereval(pTHX);
-PERL_CALLCONV OP * Perl_pp_entergiven(pTHX);
-PERL_CALLCONV OP * Perl_pp_enteriter(pTHX);
-PERL_CALLCONV OP * Perl_pp_enterloop(pTHX);
-PERL_CALLCONV OP * Perl_pp_entersub(pTHX);
-PERL_CALLCONV OP * Perl_pp_entertry(pTHX);
-PERL_CALLCONV OP * Perl_pp_enterwhen(pTHX);
-PERL_CALLCONV OP * Perl_pp_enterwrite(pTHX);
-PERL_CALLCONV OP * Perl_pp_eof(pTHX);
-PERL_CALLCONV OP * Perl_pp_eprotoent(pTHX);
-PERL_CALLCONV OP * Perl_pp_epwent(pTHX);
-PERL_CALLCONV OP * Perl_pp_eq(pTHX);
-PERL_CALLCONV OP * Perl_pp_eservent(pTHX);
-PERL_CALLCONV OP * Perl_pp_exec(pTHX);
-PERL_CALLCONV OP * Perl_pp_exists(pTHX);
-PERL_CALLCONV OP * Perl_pp_exit(pTHX);
-PERL_CALLCONV OP * Perl_pp_exp(pTHX);
-PERL_CALLCONV OP * Perl_pp_fcntl(pTHX);
-PERL_CALLCONV OP * Perl_pp_fileno(pTHX);
-PERL_CALLCONV OP * Perl_pp_flip(pTHX);
-PERL_CALLCONV OP * Perl_pp_flock(pTHX);
-PERL_CALLCONV OP * Perl_pp_flop(pTHX);
-PERL_CALLCONV OP * Perl_pp_fork(pTHX);
-PERL_CALLCONV OP * Perl_pp_formline(pTHX);
-PERL_CALLCONV OP * Perl_pp_ftatime(pTHX);
-PERL_CALLCONV OP * Perl_pp_ftbinary(pTHX);
-PERL_CALLCONV OP * Perl_pp_ftblk(pTHX);
-PERL_CALLCONV OP * Perl_pp_ftchr(pTHX);
-PERL_CALLCONV OP * Perl_pp_ftctime(pTHX);
-PERL_CALLCONV OP * Perl_pp_ftdir(pTHX);
-PERL_CALLCONV OP * Perl_pp_fteexec(pTHX);
-PERL_CALLCONV OP * Perl_pp_fteowned(pTHX);
-PERL_CALLCONV OP * Perl_pp_fteread(pTHX);
-PERL_CALLCONV OP * Perl_pp_ftewrite(pTHX);
-PERL_CALLCONV OP * Perl_pp_ftfile(pTHX);
-PERL_CALLCONV OP * Perl_pp_ftis(pTHX);
-PERL_CALLCONV OP * Perl_pp_ftlink(pTHX);
-PERL_CALLCONV OP * Perl_pp_ftmtime(pTHX);
-PERL_CALLCONV OP * Perl_pp_ftpipe(pTHX);
-PERL_CALLCONV OP * Perl_pp_ftrexec(pTHX);
-PERL_CALLCONV OP * Perl_pp_ftrowned(pTHX);
-PERL_CALLCONV OP * Perl_pp_ftrread(pTHX);
-PERL_CALLCONV OP * Perl_pp_ftrwrite(pTHX);
-PERL_CALLCONV OP * Perl_pp_ftsgid(pTHX);
-PERL_CALLCONV OP * Perl_pp_ftsize(pTHX);
-PERL_CALLCONV OP * Perl_pp_ftsock(pTHX);
-PERL_CALLCONV OP * Perl_pp_ftsuid(pTHX);
-PERL_CALLCONV OP * Perl_pp_ftsvtx(pTHX);
-PERL_CALLCONV OP * Perl_pp_fttext(pTHX);
-PERL_CALLCONV OP * Perl_pp_fttty(pTHX);
-PERL_CALLCONV OP * Perl_pp_ftzero(pTHX);
-PERL_CALLCONV OP * Perl_pp_ge(pTHX);
-PERL_CALLCONV OP * Perl_pp_gelem(pTHX);
-PERL_CALLCONV OP * Perl_pp_getc(pTHX);
-PERL_CALLCONV OP * Perl_pp_getlogin(pTHX);
-PERL_CALLCONV OP * Perl_pp_getpeername(pTHX);
-PERL_CALLCONV OP * Perl_pp_getpgrp(pTHX);
-PERL_CALLCONV OP * Perl_pp_getppid(pTHX);
-PERL_CALLCONV OP * Perl_pp_getpriority(pTHX);
-PERL_CALLCONV OP * Perl_pp_getsockname(pTHX);
-PERL_CALLCONV OP * Perl_pp_ggrent(pTHX);
-PERL_CALLCONV OP * Perl_pp_ggrgid(pTHX);
-PERL_CALLCONV OP * Perl_pp_ggrnam(pTHX);
-PERL_CALLCONV OP * Perl_pp_ghbyaddr(pTHX);
-PERL_CALLCONV OP * Perl_pp_ghbyname(pTHX);
-PERL_CALLCONV OP * Perl_pp_ghostent(pTHX);
-PERL_CALLCONV OP * Perl_pp_glob(pTHX);
-PERL_CALLCONV OP * Perl_pp_gmtime(pTHX);
-PERL_CALLCONV OP * Perl_pp_gnbyaddr(pTHX);
-PERL_CALLCONV OP * Perl_pp_gnbyname(pTHX);
-PERL_CALLCONV OP * Perl_pp_gnetent(pTHX);
-PERL_CALLCONV OP * Perl_pp_goto(pTHX);
-PERL_CALLCONV OP * Perl_pp_gpbyname(pTHX);
-PERL_CALLCONV OP * Perl_pp_gpbynumber(pTHX);
-PERL_CALLCONV OP * Perl_pp_gprotoent(pTHX);
-PERL_CALLCONV OP * Perl_pp_gpwent(pTHX);
-PERL_CALLCONV OP * Perl_pp_gpwnam(pTHX);
-PERL_CALLCONV OP * Perl_pp_gpwuid(pTHX);
-PERL_CALLCONV OP * Perl_pp_grepstart(pTHX);
-PERL_CALLCONV OP * Perl_pp_grepwhile(pTHX);
-PERL_CALLCONV OP * Perl_pp_gsbyname(pTHX);
-PERL_CALLCONV OP * Perl_pp_gsbyport(pTHX);
-PERL_CALLCONV OP * Perl_pp_gservent(pTHX);
-PERL_CALLCONV OP * Perl_pp_gsockopt(pTHX);
-PERL_CALLCONV OP * Perl_pp_gt(pTHX);
-PERL_CALLCONV OP * Perl_pp_gv(pTHX);
-PERL_CALLCONV OP * Perl_pp_gvsv(pTHX);
-PERL_CALLCONV OP * Perl_pp_helem(pTHX);
-PERL_CALLCONV OP * Perl_pp_hex(pTHX);
-PERL_CALLCONV OP * Perl_pp_hintseval(pTHX);
-PERL_CALLCONV OP * Perl_pp_hslice(pTHX);
-PERL_CALLCONV OP * Perl_pp_i_add(pTHX);
-PERL_CALLCONV OP * Perl_pp_i_divide(pTHX);
-PERL_CALLCONV OP * Perl_pp_i_eq(pTHX);
-PERL_CALLCONV OP * Perl_pp_i_ge(pTHX);
-PERL_CALLCONV OP * Perl_pp_i_gt(pTHX);
-PERL_CALLCONV OP * Perl_pp_i_le(pTHX);
-PERL_CALLCONV OP * Perl_pp_i_lt(pTHX);
-PERL_CALLCONV OP * Perl_pp_i_modulo(pTHX);
-PERL_CALLCONV OP * Perl_pp_i_multiply(pTHX);
-PERL_CALLCONV OP * Perl_pp_i_ncmp(pTHX);
-PERL_CALLCONV OP * Perl_pp_i_ne(pTHX);
-PERL_CALLCONV OP * Perl_pp_i_negate(pTHX);
-PERL_CALLCONV OP * Perl_pp_i_subtract(pTHX);
-PERL_CALLCONV OP * Perl_pp_index(pTHX);
-PERL_CALLCONV OP * Perl_pp_int(pTHX);
-PERL_CALLCONV OP * Perl_pp_ioctl(pTHX);
-PERL_CALLCONV OP * Perl_pp_iter(pTHX);
-PERL_CALLCONV OP * Perl_pp_join(pTHX);
-PERL_CALLCONV OP * Perl_pp_keys(pTHX);
-PERL_CALLCONV OP * Perl_pp_kill(pTHX);
-PERL_CALLCONV OP * Perl_pp_last(pTHX);
-PERL_CALLCONV OP * Perl_pp_lc(pTHX);
-PERL_CALLCONV OP * Perl_pp_lcfirst(pTHX);
-PERL_CALLCONV OP * Perl_pp_le(pTHX);
-PERL_CALLCONV OP * Perl_pp_leave(pTHX);
-PERL_CALLCONV OP * Perl_pp_leaveeval(pTHX);
-PERL_CALLCONV OP * Perl_pp_leavegiven(pTHX);
-PERL_CALLCONV OP * Perl_pp_leaveloop(pTHX);
-PERL_CALLCONV OP * Perl_pp_leavesub(pTHX);
-PERL_CALLCONV OP * Perl_pp_leavesublv(pTHX);
-PERL_CALLCONV OP * Perl_pp_leavetry(pTHX);
-PERL_CALLCONV OP * Perl_pp_leavewhen(pTHX);
-PERL_CALLCONV OP * Perl_pp_leavewrite(pTHX);
-PERL_CALLCONV OP * Perl_pp_left_shift(pTHX);
-PERL_CALLCONV OP * Perl_pp_length(pTHX);
-PERL_CALLCONV OP * Perl_pp_lineseq(pTHX);
-PERL_CALLCONV OP * Perl_pp_link(pTHX);
-PERL_CALLCONV OP * Perl_pp_list(pTHX);
-PERL_CALLCONV OP * Perl_pp_listen(pTHX);
-PERL_CALLCONV OP * Perl_pp_localtime(pTHX);
-PERL_CALLCONV OP * Perl_pp_lock(pTHX);
-PERL_CALLCONV OP * Perl_pp_log(pTHX);
-PERL_CALLCONV OP * Perl_pp_lslice(pTHX);
-PERL_CALLCONV OP * Perl_pp_lstat(pTHX);
-PERL_CALLCONV OP * Perl_pp_lt(pTHX);
-PERL_CALLCONV OP * Perl_pp_mapstart(pTHX);
-PERL_CALLCONV OP * Perl_pp_mapwhile(pTHX);
-PERL_CALLCONV OP * Perl_pp_match(pTHX);
-PERL_CALLCONV OP * Perl_pp_method(pTHX);
-PERL_CALLCONV OP * Perl_pp_method_named(pTHX);
-PERL_CALLCONV OP * Perl_pp_mkdir(pTHX);
-PERL_CALLCONV OP * Perl_pp_modulo(pTHX);
-PERL_CALLCONV OP * Perl_pp_msgctl(pTHX);
-PERL_CALLCONV OP * Perl_pp_msgget(pTHX);
-PERL_CALLCONV OP * Perl_pp_msgrcv(pTHX);
-PERL_CALLCONV OP * Perl_pp_msgsnd(pTHX);
-PERL_CALLCONV OP * Perl_pp_multiply(pTHX);
-PERL_CALLCONV OP * Perl_pp_ncmp(pTHX);
-PERL_CALLCONV OP * Perl_pp_ne(pTHX);
-PERL_CALLCONV OP * Perl_pp_negate(pTHX);
-PERL_CALLCONV OP * Perl_pp_next(pTHX);
-PERL_CALLCONV OP * Perl_pp_nextstate(pTHX);
-PERL_CALLCONV OP * Perl_pp_not(pTHX);
-PERL_CALLCONV OP * Perl_pp_null(pTHX);
-PERL_CALLCONV OP * Perl_pp_oct(pTHX);
-PERL_CALLCONV OP * Perl_pp_once(pTHX);
-PERL_CALLCONV OP * Perl_pp_open(pTHX);
-PERL_CALLCONV OP * Perl_pp_open_dir(pTHX);
-PERL_CALLCONV OP * Perl_pp_or(pTHX);
-PERL_CALLCONV OP * Perl_pp_orassign(pTHX);
-PERL_CALLCONV OP * Perl_pp_ord(pTHX);
-PERL_CALLCONV OP * Perl_pp_pack(pTHX);
-PERL_CALLCONV OP * Perl_pp_padany(pTHX);
-PERL_CALLCONV OP * Perl_pp_padav(pTHX);
-PERL_CALLCONV OP * Perl_pp_padhv(pTHX);
-PERL_CALLCONV OP * Perl_pp_padsv(pTHX);
-PERL_CALLCONV OP * Perl_pp_pipe_op(pTHX);
-PERL_CALLCONV OP * Perl_pp_pop(pTHX);
-PERL_CALLCONV OP * Perl_pp_pos(pTHX);
-PERL_CALLCONV OP * Perl_pp_postdec(pTHX);
-PERL_CALLCONV OP * Perl_pp_postinc(pTHX);
-PERL_CALLCONV OP * Perl_pp_pow(pTHX);
-PERL_CALLCONV OP * Perl_pp_predec(pTHX);
-PERL_CALLCONV OP * Perl_pp_preinc(pTHX);
-PERL_CALLCONV OP * Perl_pp_print(pTHX);
-PERL_CALLCONV OP * Perl_pp_prototype(pTHX);
-PERL_CALLCONV OP * Perl_pp_prtf(pTHX);
-PERL_CALLCONV OP * Perl_pp_push(pTHX);
-PERL_CALLCONV OP * Perl_pp_pushmark(pTHX);
-PERL_CALLCONV OP * Perl_pp_pushre(pTHX);
-PERL_CALLCONV OP * Perl_pp_qr(pTHX);
-PERL_CALLCONV OP * Perl_pp_quotemeta(pTHX);
-PERL_CALLCONV OP * Perl_pp_rand(pTHX);
-PERL_CALLCONV OP * Perl_pp_range(pTHX);
-PERL_CALLCONV OP * Perl_pp_rcatline(pTHX);
-PERL_CALLCONV OP * Perl_pp_reach(pTHX);
-PERL_CALLCONV OP * Perl_pp_read(pTHX);
-PERL_CALLCONV OP * Perl_pp_readdir(pTHX);
-PERL_CALLCONV OP * Perl_pp_readline(pTHX);
-PERL_CALLCONV OP * Perl_pp_readlink(pTHX);
-PERL_CALLCONV OP * Perl_pp_recv(pTHX);
-PERL_CALLCONV OP * Perl_pp_redo(pTHX);
-PERL_CALLCONV OP * Perl_pp_ref(pTHX);
-PERL_CALLCONV OP * Perl_pp_refgen(pTHX);
-PERL_CALLCONV OP * Perl_pp_regcmaybe(pTHX);
-PERL_CALLCONV OP * Perl_pp_regcomp(pTHX);
-PERL_CALLCONV OP * Perl_pp_regcreset(pTHX);
-PERL_CALLCONV OP * Perl_pp_rename(pTHX);
-PERL_CALLCONV OP * Perl_pp_repeat(pTHX);
-PERL_CALLCONV OP * Perl_pp_require(pTHX);
-PERL_CALLCONV OP * Perl_pp_reset(pTHX);
-PERL_CALLCONV OP * Perl_pp_return(pTHX);
-PERL_CALLCONV OP * Perl_pp_reverse(pTHX);
-PERL_CALLCONV OP * Perl_pp_rewinddir(pTHX);
-PERL_CALLCONV OP * Perl_pp_right_shift(pTHX);
-PERL_CALLCONV OP * Perl_pp_rindex(pTHX);
-PERL_CALLCONV OP * Perl_pp_rkeys(pTHX);
-PERL_CALLCONV OP * Perl_pp_rmdir(pTHX);
-PERL_CALLCONV OP * Perl_pp_rv2av(pTHX);
-PERL_CALLCONV OP * Perl_pp_rv2cv(pTHX);
-PERL_CALLCONV OP * Perl_pp_rv2gv(pTHX);
-PERL_CALLCONV OP * Perl_pp_rv2hv(pTHX);
-PERL_CALLCONV OP * Perl_pp_rv2sv(pTHX);
-PERL_CALLCONV OP * Perl_pp_rvalues(pTHX);
-PERL_CALLCONV OP * Perl_pp_sassign(pTHX);
-PERL_CALLCONV OP * Perl_pp_say(pTHX);
-PERL_CALLCONV OP * Perl_pp_scalar(pTHX);
-PERL_CALLCONV OP * Perl_pp_schomp(pTHX);
-PERL_CALLCONV OP * Perl_pp_schop(pTHX);
-PERL_CALLCONV OP * Perl_pp_scmp(pTHX);
-PERL_CALLCONV OP * Perl_pp_scope(pTHX);
-PERL_CALLCONV OP * Perl_pp_seek(pTHX);
-PERL_CALLCONV OP * Perl_pp_seekdir(pTHX);
-PERL_CALLCONV OP * Perl_pp_select(pTHX);
-PERL_CALLCONV OP * Perl_pp_semctl(pTHX);
-PERL_CALLCONV OP * Perl_pp_semget(pTHX);
-PERL_CALLCONV OP * Perl_pp_semop(pTHX);
-PERL_CALLCONV OP * Perl_pp_send(pTHX);
-PERL_CALLCONV OP * Perl_pp_seq(pTHX);
-PERL_CALLCONV OP * Perl_pp_setpgrp(pTHX);
-PERL_CALLCONV OP * Perl_pp_setpriority(pTHX);
-PERL_CALLCONV OP * Perl_pp_sge(pTHX);
-PERL_CALLCONV OP * Perl_pp_sgrent(pTHX);
-PERL_CALLCONV OP * Perl_pp_sgt(pTHX);
-PERL_CALLCONV OP * Perl_pp_shift(pTHX);
-PERL_CALLCONV OP * Perl_pp_shmctl(pTHX);
-PERL_CALLCONV OP * Perl_pp_shmget(pTHX);
-PERL_CALLCONV OP * Perl_pp_shmread(pTHX);
-PERL_CALLCONV OP * Perl_pp_shmwrite(pTHX);
-PERL_CALLCONV OP * Perl_pp_shostent(pTHX);
-PERL_CALLCONV OP * Perl_pp_shutdown(pTHX);
-PERL_CALLCONV OP * Perl_pp_sin(pTHX);
-PERL_CALLCONV OP * Perl_pp_sle(pTHX);
-PERL_CALLCONV OP * Perl_pp_sleep(pTHX);
-PERL_CALLCONV OP * Perl_pp_slt(pTHX);
-PERL_CALLCONV OP * Perl_pp_smartmatch(pTHX);
-PERL_CALLCONV OP * Perl_pp_sne(pTHX);
-PERL_CALLCONV OP * Perl_pp_snetent(pTHX);
-PERL_CALLCONV OP * Perl_pp_socket(pTHX);
-PERL_CALLCONV OP * Perl_pp_sockpair(pTHX);
-PERL_CALLCONV OP * Perl_pp_sort(pTHX);
-PERL_CALLCONV OP * Perl_pp_splice(pTHX);
-PERL_CALLCONV OP * Perl_pp_split(pTHX);
-PERL_CALLCONV OP * Perl_pp_sprintf(pTHX);
-PERL_CALLCONV OP * Perl_pp_sprotoent(pTHX);
-PERL_CALLCONV OP * Perl_pp_spwent(pTHX);
-PERL_CALLCONV OP * Perl_pp_sqrt(pTHX);
-PERL_CALLCONV OP * Perl_pp_srand(pTHX);
-PERL_CALLCONV OP * Perl_pp_srefgen(pTHX);
-PERL_CALLCONV OP * Perl_pp_sselect(pTHX);
-PERL_CALLCONV OP * Perl_pp_sservent(pTHX);
-PERL_CALLCONV OP * Perl_pp_ssockopt(pTHX);
-PERL_CALLCONV OP * Perl_pp_stat(pTHX);
-PERL_CALLCONV OP * Perl_pp_stringify(pTHX);
-PERL_CALLCONV OP * Perl_pp_stub(pTHX);
-PERL_CALLCONV OP * Perl_pp_study(pTHX);
-PERL_CALLCONV OP * Perl_pp_subst(pTHX);
-PERL_CALLCONV OP * Perl_pp_substcont(pTHX);
-PERL_CALLCONV OP * Perl_pp_substr(pTHX);
-PERL_CALLCONV OP * Perl_pp_subtract(pTHX);
-PERL_CALLCONV OP * Perl_pp_symlink(pTHX);
-PERL_CALLCONV OP * Perl_pp_syscall(pTHX);
-PERL_CALLCONV OP * Perl_pp_sysopen(pTHX);
-PERL_CALLCONV OP * Perl_pp_sysread(pTHX);
-PERL_CALLCONV OP * Perl_pp_sysseek(pTHX);
-PERL_CALLCONV OP * Perl_pp_system(pTHX);
-PERL_CALLCONV OP * Perl_pp_syswrite(pTHX);
-PERL_CALLCONV OP * Perl_pp_tell(pTHX);
-PERL_CALLCONV OP * Perl_pp_telldir(pTHX);
-PERL_CALLCONV OP * Perl_pp_tie(pTHX);
-PERL_CALLCONV OP * Perl_pp_tied(pTHX);
-PERL_CALLCONV OP * Perl_pp_time(pTHX);
-PERL_CALLCONV OP * Perl_pp_tms(pTHX);
-PERL_CALLCONV OP * Perl_pp_trans(pTHX);
-PERL_CALLCONV OP * Perl_pp_transr(pTHX);
-PERL_CALLCONV OP * Perl_pp_truncate(pTHX);
-PERL_CALLCONV OP * Perl_pp_uc(pTHX);
-PERL_CALLCONV OP * Perl_pp_ucfirst(pTHX);
-PERL_CALLCONV OP * Perl_pp_umask(pTHX);
-PERL_CALLCONV OP * Perl_pp_undef(pTHX);
-PERL_CALLCONV OP * Perl_pp_unlink(pTHX);
-PERL_CALLCONV OP * Perl_pp_unpack(pTHX);
-PERL_CALLCONV OP * Perl_pp_unshift(pTHX);
-PERL_CALLCONV OP * Perl_pp_unstack(pTHX);
-PERL_CALLCONV OP * Perl_pp_untie(pTHX);
-PERL_CALLCONV OP * Perl_pp_utime(pTHX);
-PERL_CALLCONV OP * Perl_pp_values(pTHX);
-PERL_CALLCONV OP * Perl_pp_vec(pTHX);
-PERL_CALLCONV OP * Perl_pp_wait(pTHX);
-PERL_CALLCONV OP * Perl_pp_waitpid(pTHX);
-PERL_CALLCONV OP * Perl_pp_wantarray(pTHX);
-PERL_CALLCONV OP * Perl_pp_warn(pTHX);
-PERL_CALLCONV OP * Perl_pp_xor(pTHX);
PERL_CALLCONV REGEXP* Perl_pregcomp(pTHX_ SV * const pattern, const U32 flags)
__attribute__nonnull__(pTHX_1);
#define PERL_ARGS_ASSERT_PREGCOMP \
@@ -7450,5 +7085,8 @@ PERL_CALLCONV int Perl_do_spawn_nowait(pTHX_ char* cmd)
assert(cmd)
#endif
+#ifdef PERL_CORE
+# include "pp_proto.h"
+#endif
END_EXTERN_C
/* ex: set ro: */
diff --git a/regen.pl b/regen.pl
index 4f3be80d3a..277413c587 100644
--- a/regen.pl
+++ b/regen.pl
@@ -13,8 +13,7 @@ require 5.004; # keep this compatible, an old perl is all we may have before
use strict;
-# Which scripts to run. Note the ordering: embed.pl must run after
-# opcode.pl, since it depends on pp.sym
+# Which scripts to run.
my @scripts = qw(
keywords.pl
diff --git a/regen/embed.pl b/regen/embed.pl
index 2a7d344e65..d6aef5a7c7 100755
--- a/regen/embed.pl
+++ b/regen/embed.pl
@@ -14,7 +14,7 @@
# embed.fnc
# intrpvar.h
# perlvars.h
-# pp.sym (which has been generated by opcode.pl)
+# regen/opcodes
#
# Accepts the standard regen_lib -q and -v args.
#
@@ -60,7 +60,7 @@ sub do_not_edit ($)
!!!!!!! DO NOT EDIT THIS FILE !!!!!!!
This file is built by regen/embed.pl from data in embed.fnc,
-regen/embed.pl, pp.sym, intrpvar.h, and perlvars.h.
+regen/embed.pl, regen/opcodes intrpvar.h, and perlvars.h.
Any changes made here will be lost!
Edit those files and run 'make regen_headers' to effect changes.
@@ -142,31 +142,6 @@ open IN, 'regen/opcodes' or die $!;
}
close IN;
-open IN, 'pp.sym' or die $!;
-{
- my %syms;
-
- while (<IN>) {
- s/[ \t]*#.*//; # Delete comments.
- if (/^\s*(\S+)\s*$/) {
- my $sym = $1;
- warn "duplicate symbol $sym while processing 'pp.sym' line $.\n"
- if $syms{$sym}++;
- }
- }
-
- foreach (sort keys %syms) {
- s/^Perl_//;
- if (/^pp_/) {
- push @embed, ['p', 'OP *', $_];
- }
- else {
- warn "Illegal symbol '$_' in pp.sym";
- }
- }
-}
-close IN;
-
my (@core, @ext, @api);
{
# Cluster entries in embed.fnc that have the same #ifdef guards.
@@ -393,7 +368,13 @@ sub walk_table (&@) {
print $pr $ret;
}
- print $pr "END_EXTERN_C\n/* ex: set ro: */\n";
+ print $pr <<'EOF';
+#ifdef PERL_CORE
+# include "pp_proto.h"
+#endif
+END_EXTERN_C
+/* ex: set ro: */
+EOF
safer_close($pr);
rename_if_different('proto.h-new', 'proto.h');
diff --git a/regen/opcode.pl b/regen/opcode.pl
index a8f5e0b845..dd53aec81b 100755
--- a/regen/opcode.pl
+++ b/regen/opcode.pl
@@ -4,7 +4,7 @@
#
# opcode.h
# opnames.h
-# pp.sym
+# pp_proto.h
#
# from information stored in regen/opcodes, plus the
# values hardcoded into this script in @raw_alias.
@@ -468,33 +468,32 @@ safer_close($on);
rename_if_different $opcode_new, 'opcode.h';
rename_if_different $opname_new, 'opnames.h';
-my $pp_sym_new = 'pp.sym-new';
-my $ppsym = safer_open($pp_sym_new);
+my $pp_proto_new = 'pp_proto.h-new';
-print $ppsym <<"END";
-# -*- buffer-read-only: t -*-
-#
-# !!!!!!! DO NOT EDIT THIS FILE !!!!!!!
-# This file is built by regen/opcode.pl from its data. Any changes made
-# here will be lost!
-#
+my $pp = safer_open($pp_proto_new);
-END
+print $pp <<"END";
+/* -*- buffer-read-only: t -*-
+ !!!!!!! DO NOT EDIT THIS FILE !!!!!!!
+ This file is built by opcode.pl from its data. Any changes made here
+ will be lost!
+*/
+END
-for (@ops) {
+for (sort @ops) {
next if /^i_(pre|post)(inc|dec)$/;
next if /^custom$/;
- print $ppsym "Perl_pp_$_\n";
+ print $pp "PERL_CALLCONV OP *Perl_pp_$_(pTHX);\n";
}
-print $ppsym "\n# ex: set ro:\n";
+print $pp "\n/* ex: set ro: */\n";
-safer_close($ppsym);
+safer_close($pp);
-rename_if_different $pp_sym_new, 'pp.sym';
+rename_if_different $pp_proto_new, 'pp_proto.h';
END {
- foreach ('opcode.h', 'opnames.h', 'pp.sym') {
+ foreach ('opcode.h', 'opnames.h', 'pp_proto.h') {
1 while unlink "$_-old";
}
}
diff --git a/vms/descrip_mms.template b/vms/descrip_mms.template
index 213d8ad8b2..ea70c32567 100644
--- a/vms/descrip_mms.template
+++ b/vms/descrip_mms.template
@@ -1457,9 +1457,8 @@ $(SOCKH) : [.vms]$(SOCKH)
# The following files are generated automatically
# embed.pl: proto.h embed.h embedvar.h global.sym
# perlapi.h perlapi.c
-# [* embed.pl needs pp.sym generated by opcode.pl! *]
# keywords.pl: keywords.h
-# opcode.pl: opcode.h opnames.h pp.sym
+# opcode.pl: opcode.h opnames.h pp_proto.h
# regcomp.pl: regnodes.h
# warnings.pl: warnings.h lib/warnings.pm
# The correct versions should be already supplied with the perl kit,
diff --git a/win32/Makefile b/win32/Makefile
index 79040792e6..e0e7835234 100644
--- a/win32/Makefile
+++ b/win32/Makefile
@@ -889,7 +889,7 @@ $(CORE_OBJ) : $(CORE_H)
$(DLL_OBJ) : $(CORE_H)
$(X2P_OBJ) : $(CORE_H)
-perldll.def : $(MINIPERL) $(CONFIGPM) ..\global.sym ..\pp.sym ..\makedef.pl create_perllibst_h.pl
+perldll.def : $(MINIPERL) $(CONFIGPM) ..\global.sym ..\makedef.pl create_perllibst_h.pl
$(MINIPERL) -I..\lib create_perllibst_h.pl
$(MINIPERL) -I..\lib -w ..\makedef.pl PLATFORM=win32 $(OPTIMIZE) $(DEFINES) $(BUILDOPT) \
CCTYPE=$(CCTYPE) > perldll.def
diff --git a/win32/Makefile.ce b/win32/Makefile.ce
index af2d5d7fda..9052ca8c64 100644
--- a/win32/Makefile.ce
+++ b/win32/Makefile.ce
@@ -844,7 +844,7 @@ $(DLLDIR)\perllib$(o) : perllib.c .\perlhost.h .\vdir.h .\vmem.h
rem (frustrated) mv perllib.obj $(DLLDIR)
!ENDIF
-perldll.def : $(HPERL) $(CONFIGPM) ..\global.sym ..\pp.sym ..\makedef.pl create_perllibst_h.pl
+perldll.def : $(HPERL) $(CONFIGPM) ..\global.sym ..\makedef.pl create_perllibst_h.pl
$(HPERL) -MCross -I..\lib create_perllibst_h.pl
$(HPERL) -w ..\makedef.pl PLATFORM=wince $(OPTIMIZE) $(DEFINES) $(BUILDOPT) \
CCTYPE=$(CCTYPE) -DPERL_DLL=$(PERLDLL) > perldll.def
diff --git a/win32/makefile.mk b/win32/makefile.mk
index f85dcc917a..9d23a73371 100644
--- a/win32/makefile.mk
+++ b/win32/makefile.mk
@@ -1208,7 +1208,7 @@ $(DLL_OBJ) : $(CORE_H)
$(X2P_OBJ) : $(CORE_H)
-perldll.def : $(MINIPERL) $(CONFIGPM) ..\global.sym ..\pp.sym ..\makedef.pl create_perllibst_h.pl
+perldll.def : $(MINIPERL) $(CONFIGPM) ..\global.sym ..\makedef.pl create_perllibst_h.pl
$(MINIPERL) -I..\lib create_perllibst_h.pl
$(MINIPERL) -I..\lib -w ..\makedef.pl PLATFORM=win32 $(OPTIMIZE) $(DEFINES) \
$(BUILDOPT) CCTYPE=$(CCTYPE) > perldll.def
diff --git a/Makefile.SH b/Makefile.SH
index a34416a9a4..c75cd50274 100755
--- a/Makefile.SH
+++ b/Makefile.SH
@@ -1110,7 +1110,7 @@ perly.h: perly.y
# No compat3.sym here since and including the 5.004_50.
# No interp.sym since 5.005_03.
-SYM = global.sym globvar.sym perlio.sym pp.sym
+SYM = global.sym globvar.sym perlio.sym
SYMH = perlvars.h intrpvar.h
@@ -1119,9 +1119,8 @@ CHMOD_W = chmod +w
# The following files are generated automatically
# embed.pl: proto.h embed.h embedvar.h global.sym
# perlapi.h perlapi.c
-# [* embed.pl needs pp.sym generated by opcode.pl! *]
# keywords.pl: keywords.h
# opcode.pl: opcode.h opnames.h pp.sym
# regcomp.pl: regnodes.h
# warnings.pl: warnings.h lib/warnings.pm
# The correct versions should be already supplied with the perl kit,
@@ -1131,7 +1130,7 @@ CHMOD_W = chmod +w
# with your existing copy of perl
# (make regen_headers is kept for backwards compatibility)
-AUTOGEN_FILES = keywords.h opcode.h opnames.h pp.sym proto.h \
+AUTOGEN_FILES = keywords.h opcode.h opnames.h pp_proto.h proto.h \
embed.h embedvar.h global.sym \
perlapi.h perlapi.c regnodes.h \
warnings.h lib/warnings.pm
@@ -1230,7 +1229,7 @@ _mopup:
-rm -f perl.Addrs perl.Counts t/perl.Addrs t/perl.Counts *perl.xok
-rm -f cygwin.c libperl*.def libperl*.dll cygperl*.dll *.exe.stackdump
-rm -f $(PERL_EXE) $(MINIPERL_EXE) $(LIBPERL) libperl.* microperl
- -rm -f opcode.h-old opnames.h-old pp.sym-old
+ -rm -f opcode.h-old opnames.h-old pp_proto.h-old
-rm -f config.arch config.over $(DTRACE_H) runtests
# Do not 'make _tidy' directly.
@@ -1119,9 +1119,8 @@ CHMOD_W = chmod +w
# keywords.pl: keywords.h
-# opcode.pl: opcode.h opnames.h pp.sym
+# opcode.pl: opcode.h opnames.h pp_proto.h
# regcomp.pl: regnodes.h
# warnings.pl: warnings.h lib/warnings.pm